<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Services Widget.
 *
 * @since 1.0
 */
class Kinsley_Contact_Info_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-contact-info';
	}

	public function get_title() {
		return esc_html__( 'Contact Info', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'lines',
			[
				'label'       => esc_html__( 'Lines', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'layout',
			[
				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'column-3',
				'options' => [
					'column-1'  => __( '1 Columns', 'kinsley-plugin' ),
					'column-2'  => __( '2 Columns', 'kinsley-plugin' ),
					'column-3' => __( '3 Columns', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'image', [
				'label' => esc_html__( 'Image', 'kinsley-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'title', [
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Enter title', 'kinsley-plugin' ),
			]
		);

		$repeater->add_control(
			'desc', [
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Description', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'items',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'prevent_empty' => false,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-features-card .knsl-icon-box h5' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-features-card .knsl-icon-box h5',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-features-card .knsl-icon-box p' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-features-card .knsl-icon-box p',
			]
		);

		$this->add_control(
			'item_bgcolor',
			[
				'label'     => esc_html__( 'Item BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-features-card .knsl-icon-box' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$cols_classes = 'col-12 col-lg-4';

		if ( $settings['layout'] == 'column-2' ) {
			$cols_classes = 'col-12 col-lg-6';
		} elseif ( $settings['layout'] == 'column-1' ) {
			$cols_classes = 'col-12 col-lg-12';
		} else {}

		?>

		<!-- contact -->
    <section>

      <div id="knsl-triger-1"></div>

      <div class="container">

        <!-- features card -->
        <div class="knsl-features-card<?php if ( $settings['lines'] != 'yes' ) : ?> knsl-features-card-no-lines<?php endif; ?>">
					<?php if ( $settings['items'] ) : ?>
          <div class="row">
						<?php foreach ( $settings['items'] as $index => $item ) :
						  $item_title = $this->get_repeater_setting_key( 'title', 'items', $index );
						  $this->add_inline_editing_attributes( $item_title, 'basic' );

						  $item_desc = $this->get_repeater_setting_key( 'desc', 'items', $index );
						  $this->add_inline_editing_attributes( $item_desc, 'basic' );
					  ?>
            <div class="<?php echo esc_attr( $cols_classes ); ?>">

              <!-- icon box -->
              <div class="knsl-icon-box">
								<?php if ( $item['image'] ) : $image = wp_get_attachment_image_url( $item['image']['id'], 'kinsley_140x140' ); ?>
                <img src="<?php echo esc_url( $image ); ?>" alt="icon" class="knsl-mb-10" />
								<?php endif; ?>
								<?php if ( $item['title'] ) : ?>
                <h5 class="knsl-mb-10">
									<span <?php echo $this->get_render_attribute_string( $item_title ); ?>>
										<?php echo wp_kses_post( $item['title'] ); ?>
									</span>
								</h5>
								<?php endif; ?>
								<?php if ( $item['desc'] ) : ?>
                <p>
									<span <?php echo $this->get_render_attribute_string( $item_desc ); ?>>
										<?php echo wp_kses_post( $item['desc'] ); ?>
									</span>
								</p>
								<?php endif; ?>
              </div>
              <!-- icon box end -->

            </div>
						<?php endforeach; ?>
          </div>
					<?php endif; ?>
        </div>
        <!-- contact end -->

      </div>
    </section>

		<?php
	}

	/**
	 * Render widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template() {

		?>

		<#
		var cols_classes = 'col-12 col-lg-4';

		if ( settings.layout == 'column-2' ) {
			cols_classes = 'col-12 col-lg-6';
		}
		if ( settings.layout == 'column-1' ) {
			cols_classes = 'col-12 col-lg-12';
		}

		#>

		<!-- contact -->
    <section>

      <div id="knsl-triger-1"></div>

      <div class="container">

        <!-- features card -->
        <div class="knsl-features-card<# if ( settings.lines != 'no' ) { #> knsl-features-card-no-lines<# } #>">
					<# if ( settings.items ) { #>
          <div class="row">
						<# _.each( settings.items, function( item, index ) {
							var item_title = view.getRepeaterSettingKey( 'title', 'items', index );
							view.addInlineEditingAttributes( item_title, 'basic' );

							var item_desc = view.getRepeaterSettingKey( 'desc', 'items', index );
							view.addInlineEditingAttributes( item_desc, 'basic' );
					  #>
            <div class="{{{ cols_classes }}}">

              <!-- icon box -->
              <div class="knsl-icon-box">
								<# if ( item.image ) { #>
                <img src="{{{ item.image.url }}}" alt="icon" class="knsl-mb-10" />
								<# } #>
								<# if ( item.title ) { #>
                <h5 class="knsl-mb-10">
									<span {{{ view.getRenderAttributeString( item_title ) }}}>
										{{{ item.title }}}
									</span>
								</h5>
								<# } #>
								<# if ( item.desc ) { #>
                <p>
									<span {{{ view.getRenderAttributeString( item_desc ) }}}>
										{{{ item.desc }}}
									</span>
								</p>
								<# } #>
              </div>
              <!-- icon box end -->

            </div>
						<# }); #>
          </div>
					<# } #>
        </div>
        <!-- contact end -->

      </div>
    </section>

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Contact_Info_Widget() );
