<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley FAQ List Widget.
 *
 * @since 1.0
 */
class Kinsley_Faq_List_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-faq-list';
	}

	public function get_title() {
		return esc_html__( 'FAQ (List)', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => esc_html__( 'Heading', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'menu_title',
			[
				'label'       => esc_html__( 'Left Side Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'categories' => __( 'Categories', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_categories',
			[
				'label'       => esc_html__( 'Categories', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_faq_categories(),
				'condition' => [
            'source' => 'categories'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 6,
				'default'     => 6,
			]
		);

		$this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date'  => __( 'Date', 'kinsley-plugin' ),
					'title' => __( 'Title', 'kinsley-plugin' ),
					'rand' => __( 'Random', 'kinsley-plugin' ),
					'menu_order' => __( 'Order', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc'  => __( 'ASC', 'kinsley-plugin' ),
					'desc' => __( 'DESC', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'form_tab',
			[
				'label' => esc_html__( 'Form', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'form_title',
			[
				'label'       => esc_html__( 'Form Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'faq_form',
			[
				'label' => esc_html__( 'Select CF7 Form', 'kinsley-plugin' ),
				'type' => Controls_Manager::SELECT,
				'default' => 1,
				'options' => $this->contact_form_list(),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'category_styling',
			[
				'label'     => esc_html__( 'Category', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'category_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-sticky h3, {{WRAPPER}} #accordion h3' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'category_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-sticky h3, {{WRAPPER}} #accordion h3',
			]
		);

		$this->add_control(
			'category_bgcolor',
			[
				'label'     => esc_html__( 'Category BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-side-menu' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'category_link_color',
			[
				'label'     => esc_html__( 'Link Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-side-menu .knsl-sm-link' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'category_link_typography',
				'label'     => esc_html__( 'Link Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-side-menu .knsl-sm-link',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_bg_color',
			[
				'label'     => esc_html__( 'Item BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-faq' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-faq .card .card-header .knsl-faq-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-faq .card .card-header .knsl-faq-title',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-faq .card .knsl-card-body' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-faq .card .knsl-card-body',
			]
		);

		$this->add_control(
			'item_badge_color',
			[
				'label'     => esc_html__( 'Badge Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-faq .card .card-header .knsl-faq-title .badge' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_badge_bgcolor',
			[
				'label'     => esc_html__( 'Badge BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-faq .card .card-header .knsl-faq-title .badge' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Categories List.
	 *
	 * @since 1.0
	 */
	protected function get_faq_categories() {
		$categories = [];

		$args = array(
			'type'			=> 'faq',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'faq_categories',
			'pad_counts'	=> false
		);

		$faq_categories = get_categories( $args );

		foreach ( $faq_categories as $category ) {
			$categories[$category->term_id] = $category->name;
		}

		return $categories;
	}

	/**
	 * Render Contact Form List.
	 *
	 * @since 1.0
	 */
	protected function contact_form_list() {
		$cf7_posts = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );

		$cf7_forms = array();

		if ( $cf7_posts ) {
			foreach ( $cf7_posts as $cf7_form ) {
				$cf7_forms[ $cf7_form->ID ] = $cf7_form->post_title;
			}
		} else {
			$cf7_forms[ esc_html__( 'No contact forms found', 'kinsley-plugin' ) ] = 0;
		}

		return $cf7_forms;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );
		$this->add_inline_editing_attributes( 'more', 'basic' );

		$this->add_inline_editing_attributes( 'menu_title', 'basic' );
		$this->add_inline_editing_attributes( 'form_title', 'basic' );

		$page_id = get_the_ID();
		$paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;

		$cat_ids = '';

		if ( $settings['source'] == 'categories' ) {
			$cat_ids = $settings['source_categories'];
		} else {
			$cat_ids = '';
		}

		$cat_args = array(
			'type'			=> 'faq',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'faq_categories',
			'pad_counts'	=> false,
			'include'		=> $cat_ids
		);

		$fq_categories = get_categories( $cat_args );

		?>

		<!-- faq -->
    <div class="container knsl-p-0-100">
			<?php if ( $settings['title'] || $settings['more'] || $settings['description'] ) : ?>
			<div class="row">
				<div class="col-lg-12">
					<div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
						<?php if ( $settings['title'] ) : ?>
						<<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
							<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
									<?php echo wp_kses_post( $settings['title'] ); ?>
							</span>
						</<?php echo esc_attr( $settings['title_tag'] ); ?>>
						<?php endif; ?>
						<?php if ( $settings['description'] ) : ?>
						<p class="knsl-text knsl-mb-30">
							<span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
									<?php echo wp_kses_post( $settings['description'] ); ?>
							</span>
						</p>
						<?php endif; ?>
						<?php if ( $settings['more'] ) : ?>
						<a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
							<span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
									<?php echo wp_kses_post( $settings['more'] ); ?>
							</span>
						</a>
						<?php endif; ?>
					</div>
				</div>
			</div>
			<?php endif; ?>

			<div class="row" data-sticky-container>

        <div class="col-lg-3">
					<?php if ( $fq_categories ) : ?>
          <!-- side form -->
          <div class="knsl-sticky knsl-stycky-left" data-margin-top="110">
						<?php if ( $settings['menu_title'] ) : ?>
            <h3 class="knsl-mb-30">
							<span <?php echo $this->get_render_attribute_string( 'menu_title' ); ?>>
									<?php echo wp_kses_post( $settings['menu_title'] ); ?>
							</span>
						</h3>
						<?php endif; ?>

            <ul class="knsl-side-menu">
							<?php $i = 0; foreach ( $fq_categories as $category ) : $i++; ?>
							<li><a href="#faq-<?php echo esc_attr( $category->term_id ); ?>" class="knsl-sm-link<?php if ( $i == 1 ) : ?> knsl-active<?php endif; ?>"><?php echo esc_html( $category->name ); ?></a></li>
							<?php endforeach; ?>
            </ul>

          </div>
          <!-- side form end -->
					<?php endif; ?>
        </div>
        <div class="col-lg-9">
          <section>
						<?php if ( $fq_categories ) : ?>
            <div id="accordion">
							<?php $i = 0; foreach ( $fq_categories as $category ) : $i++; ?>
              <h3 class="knsl-mb-30"><?php echo esc_html( $category->name ); ?></h3>
              <div class="knsl-faq knsl-mb-60" id="faq-<?php echo esc_attr( $category->term_id ); ?>">
								<?php

								$args = array(
									'post_type'			=> 'faq',
									'post_status'		=> 'publish',
									'orderby'			=> $settings['sort'],
									'order'				=> $settings['order'],
									'posts_per_page'	=> $settings['limit'],
									'paged' 			=> $paged,
									'tax_query'   => array(
											array(
												'taxonomy' => 'faq_categories',
												'field'    => 'id',
												'terms'    => $category->term_id
											)
									)
								);

								$q = new \WP_Query( $args );

								if ( $q->have_posts() ) : $i = 0;
									while ( $q->have_posts() ) : $q->the_post(); $i++;
										set_query_var( 'index', $i );
			          		get_template_part( 'template-parts/content', 'faq' );

									endwhile;

								else :
									get_template_part( 'template-parts/content', 'none' );
								endif; wp_reset_postdata();
								?>

              </div>
							<?php endforeach; ?>
            </div>
						<?php endif; ?>
          </section>

					<?php if ( $settings['faq_form'] ) : ?>
          <section>
            <div class="row">
              <div class="col-lg-12">
								<?php if ( $settings['form_title'] ) : ?>
								<h3 class="knsl-mb-40 knsl-scroll-animation">
									<span <?php echo $this->get_render_attribute_string( 'form_title' ); ?>>
											<?php echo wp_kses_post( $settings['form_title'] ); ?>
									</span>
								</h3>
								<?php endif; ?>
              </div>
              <div class="col-lg-12">
                <div class="knsl-scroll-animation">
                  <?php echo do_shortcode( '[contact-form-7 id="'. $settings['faq_form'] .'"]' ); ?>
                </div>
              </div>
            </div>
          </section>
					<?php endif; ?>
        </div>
      </div>
    </div>
    <!-- faq end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Faq_List_Widget() );
