<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Gallery Widget.
 *
 * @since 1.0
 */
class Kinsley_Gallery_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-gallery';
	}

	public function get_title() {
		return esc_html__( 'Gallery (Grid)', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {
    $this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => esc_html__( 'Heading', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'filters_tab',
			[
				'label' => esc_html__( 'Filters', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'filters_note',
			[
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => esc_html__( 'Filters show only with pagination "Infinite Scrolling" or "No"', 'kinsley-plugin' ),
				'content_classes' => 'elementor-descriptor',
			]
		);

		$this->add_control(
			'filters',
			[
				'label' => esc_html__( 'Show Filters', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'categories' => __( 'Categories', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_categories',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_gallery_categories(),
				'condition' => [
            'source' => 'categories'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 8,
				'default'     => 8,
			]
		);

		$this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'menu_order',
				'options' => [
					'date'  => __( 'Date', 'kinsley-plugin' ),
					'title' => __( 'Title', 'kinsley-plugin' ),
					'rand' => __( 'Random', 'kinsley-plugin' ),
					'menu_order' => __( 'Order', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'asc',
				'options' => [
					'asc'  => __( 'ASC', 'kinsley-plugin' ),
					'desc' => __( 'DESC', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pagination_tab',
			[
				'label' => esc_html__( 'Pagination', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'pagination',
			[
				'label'       => esc_html__( 'Pagination Type', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'no',
				'options' => [
					'pages' => __( 'Pages', 'kinsley-plugin' ),
					'button' => __( 'Button', 'kinsley-plugin' ),
					//'scroll' => __( 'Infinite Scrolling', 'kinsley-plugin' ),
					'no' => __( 'No', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'more_btn_txt',
			[
				'label'       => esc_html__( 'Button (title)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter button', 'kinsley-plugin' ),
				'default'     => esc_html__( 'All Posts', 'kinsley-plugin' ),
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->add_control(
			'more_btn_link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::URL,
				'show_external' => true,
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->end_controls_section();

    $this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'filters_styling',
			[
				'label'     => esc_html__( 'Filters', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'filters_color',
			[
				'label'     => esc_html__( 'Filters Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-filter .knsl-work-category' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'filters_active_color',
			[
				'label'     => esc_html__( 'Filters Active Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-filter .knsl-work-category.knsl-current' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'filters_typography',
				'label'     => esc_html__( 'Filters Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-filter .knsl-work-category',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Categories List.
	 *
	 * @since 1.0
	 */
	protected function get_gallery_categories() {
		$categories = [];

		$args = array(
			'type'			=> 'post',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'gallery_categories',
			'pad_counts'	=> false
		);

		$gallery_categories = get_categories( $args );

		foreach ( $gallery_categories as $category ) {
			$categories[$category->term_id] = $category->name;
		}

		return $categories;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'advanced' );

		$paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;
		$page_id = get_the_ID();

		if ( $settings['source'] == 'all' ) {
			$cat_ids = '';
		} else {
			$cat_ids = $settings['source_categories'];
		}

		$cat_args = array(
			'type'			=> 'post',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'gallery_categories',
			'pad_counts'	=> false,
			'include'		=> $cat_ids
		);

		$gl_categories = get_categories( $cat_args );

		$args = array(
			'post_type'			=> 'gallery',
			'post_status'		=> 'publish',
			'orderby'			=> $settings['sort'],
			'order'				=> $settings['order'],
			'posts_per_page'	=> $settings['limit'],
			'paged' 			=> $paged
		);

		if( $settings['source'] == 'categories' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'gallery_categories',
					'field'    => 'id',
					'terms'    => $cat_ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}

		$template = 'gallery';

		$q = new \WP_Query( $args );

		?>

    <!-- gallery -->
    <div class="knsl-p-0-100">
      <div class="container">
        <?php if ( $settings['heading'] == 'yes' && ( $settings['title'] || $settings['more'] || $settings['description'] ) ) : ?>
				<div class="row">
					<div class="col-lg-12">
						<div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
							<?php if ( $settings['title'] ) : ?>
							<<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
								<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
										<?php echo wp_kses_post( $settings['title'] ); ?>
								</span>
							</<?php echo esc_attr( $settings['title_tag'] ); ?>>
							<?php endif; ?>
							<?php if ( $settings['description'] ) : ?>
							<p class="knsl-text knsl-mb-30">
								<span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
										<?php echo wp_kses_post( $settings['description'] ); ?>
								</span>
							</p>
							<?php endif; ?>
							<?php if ( $settings['more'] ) : ?>
							<a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
								<span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
										<?php echo wp_kses_post( $settings['more'] ); ?>
								</span>
							</a>
							<?php endif; ?>
						</div>
					</div>
				</div>
				<?php endif; ?>

        <?php if ( $settings['filters'] && $gl_categories && $settings['pagination'] != 'pages' ) : ?>
        <div class="knsl-filter knsl-mb-60">
          <a href="#" data-filter="*" class="knsl-work-category knsl-current"><?php echo esc_html__( 'All Photos', 'kinsley-plugin' ); ?></a>
          <?php foreach ( $gl_categories as $category ) : ?>
          <a href="#" data-filter=".<?php echo esc_attr( $category->slug ); ?>" class="knsl-work-category"><?php echo esc_html( $category->name ); ?></a>
          <?php endforeach; ?>
        </div>
        <?php endif; ?>

        <?php if ( $q->have_posts() ) : ?>
        <div class="knsl-masonry-grid knsl-3-col">
          <div class="knsl-grid-sizer"></div>

          <?php $i=0; while ( $q->have_posts() ) : $q->the_post(); $i++;
						set_query_var( 'layout', 'column-3' );
						set_query_var( 'index', $i );
  					get_template_part( 'template-parts/content', 'gallery' );
  				endwhile; ?>
        </div>

        <?php if ( $settings['pagination'] == 'pages' ) : ?>
  			<div class="knsl-pagination">
  				<?php
  					$big = 999999999; // need an unlikely integer

  					echo paginate_links( array(
  						'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
  						'format' => '?paged=%#%',
  						'current' => max( 1, get_query_var('paged') ),
  						'total' => $q->max_num_pages,
  						'prev_text' => '<i class="icon-arrow-left"></i>',
  						'next_text' => '<i class="icon-arrow-right"></i>',
  					) );
  				?>
  			</div>
  			<?php endif; ?>

  			<?php if ( $settings['pagination'] == 'button' && $settings['more_btn_link'] ) : ?>
  			<div class="bts text-center">
  				<a class="knsl-btn" href="<?php echo esc_url( $settings['more_btn_link']['url'] ); ?>"<?php if ( $settings['more_btn_link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['more_btn_link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?>><?php echo esc_html( $settings['more_btn_txt'] ); ?></a>
  			</div>
  			<?php endif; ?>

  			<?php
  			if ( $settings['pagination'] == 'scroll' ) :
  				$infinite_scrolling_data = array(
  					'url'   => admin_url( 'admin-ajax.php' ),
  					'max_num' => $q->max_num_pages,
  					'page_id' => $page_id,
  					'order_by' => $settings['sort'],
  					'order' => $settings['order'],
  					'per_page' => $settings['limit'],
  					'source' => $settings['source'],
  					'temp' => $template,
  					'cat_ids' => $cat_ids,
  					'title_show' => $settings['image_title_show'],
  					'category_show' => $settings['image_category_show'],
  				);

  				wp_enqueue_script( 'kinsley-gallery-infinite-scroll-el', get_template_directory_uri() . '/assets/js/gallery-infinite-scroll-el.js', array( 'jquery' ), '1.0', true );
  				wp_localize_script( 'kinsley-gallery-infinite-scroll-el', 'ajax_gallery_infinite_scroll_data', $infinite_scrolling_data );
  			endif;
  			?>

        <?php else :
          get_template_part( 'template-parts/content', 'none' );
        endif; wp_reset_postdata(); ?>

      </div>
    </div>
    <!-- gallery end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Gallery_Widget() );
