<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Hero Banner Widget.
 *
 * @since 1.0
 */
class Kinsley_Hero_Banner_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-hero-banner';
	}

	public function get_title() {
		return esc_html__( 'Hero Banner', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {
		if ( class_exists( 'HotelBookingPlugin' ) ) {
			$minAdults   = MPHB()->settings()->main()->getMinAdults();
	    $maxAdults   = MPHB()->settings()->main()->getSearchMaxAdults();
	    $minChildren = MPHB()->settings()->main()->getMinChildren();
	    $maxChildren = MPHB()->settings()->main()->getSearchMaxChildren();
	    $dateFormat  = MPHB()->settings()->dateTime()->getDateFormat();
		} else {
			$minAdults   = 1;
	    $maxAdults   = 0;
	    $minChildren = 0;
	    $maxChildren = 0;
	    $dateFormat  = '';
		}

		$this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout',
			[
				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'style-1',
				'options' => [
					'style-1'  => __( 'Style 1', 'kinsley-plugin' ),
					'style-2' => __( 'Style 2', 'kinsley-plugin' ),
					'style-3' => __( 'Style 3', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => esc_html__( 'Subtitle', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter subtitle', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Subtitle', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'stars',
			[
				'label'       => esc_html__( 'Stars', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'search_tab',
			[
				'label' => esc_html__( 'Search', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'search',
			[
				'label'       => esc_html__( 'Accommodation Search', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control('adults', array(
        'type'        => Controls_Manager::NUMBER,
        'label'       => __('Adults', 'mphb-elementor'),
        'description' => __('The number of adults presetted in the search form.', 'mphb-elementor'),
        'default'     => $minAdults,
        'min'         => $minAdults,
        'condition' => [
  				'search' => 'yes'
  			],
        'max'         => $maxAdults
    ));

    $this->add_control('children', array(
        'type'        => Controls_Manager::NUMBER,
        'label'       => __('Children', 'mphb-elementor'),
        'description' => __('The number of children presetted in the search form.', 'mphb-elementor'),
        'default'     => $minChildren,
        'min'         => $minChildren,
        'condition' => [
      		'search' => 'yes'
      	],
        'max'         => $maxChildren
    ));

    $this->add_control('check_in_date', array(
        'type'        => Controls_Manager::TEXT,
        'label'       => __('Check-in date', 'mphb-elementor'),
        'description' => __('Check-in date presetted in the search form.', 'mphb-elementor'),
        'placeholder' => $dateFormat,
        'condition' => [
      		'search' => 'yes'
      	],
        'default'     => ''
    ));

    $this->add_control('check_out_date', array(
        'type'        => Controls_Manager::TEXT,
        'label'       => __('Check-out date', 'mphb-elementor'),
        'description' => __('Check-out date presetted in the search form.', 'mphb-elementor'),
        'placeholder' => $dateFormat,
        'condition' => [
      		'search' => 'yes'
      	],
        'default'     => ''
    ));

    $this->add_control('attributes', array(
        'type'        => Controls_Manager::TEXT,
        'label'       => __('Attributes', 'mphb-elementor'),
        'description' => __('Custom attributes for advanced search.', 'mphb-elementor'),
        'placeholder' => __('Slugs of attributes', 'mphb-elementor'),
        'condition' => [
  				'search' => 'yes'
  			],
        'default'     => ''
    ));

    $this->add_control('class', array(
        'type'        => Controls_Manager::TEXT,
        'label'       => __('Class', 'mphb-elementor'),
        'description' => __('Custom CSS class for shortcode wrapper.', 'mphb-elementor'),
        'condition' => [
      		'search' => 'yes'
      	],
        'default'     => ''
    ));

		$this->end_controls_section();

		$this->start_controls_section(
			'scroll_tab',
			[
				'label' => esc_html__( 'Scroll', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'scrolldown',
			[
				'label'       => esc_html__( 'Scroll down', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'scrolldown_text',
			[
				'label'       => esc_html__( 'Scroll down (Text)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'label_block' => true,
				'placeholder' => esc_html__( 'Scroll down', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Scroll down', 'kinsley-plugin' ),
				'condition' => [
					'scrolldown' => 'yes'
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'buttons_tab',
			[
				'label' => esc_html__( 'Buttons & Labels', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
				'condition' => [
					'layout' => 'style-3'
				]
			]
		);

		$this->add_control(
			'button_video_text',
			[
				'label'       => esc_html__( 'Video Popup Button (Label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Watch Video', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Watch Video', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'video_id',
			[
				'label'       => esc_html__( 'Video Popup (Youtube ID)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'wsq-r8lMMsk', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'wsq-r8lMMsk', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'button_search_popup_text',
			[
				'label'       => esc_html__( 'Search Popup Button (Label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Book now', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Book now', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_search_popup',
			[
				'label'       => esc_html__( 'Search Popup Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Search your Room', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Search your Room', 'kinsley-plugin' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'background_tab',
			[
				'label' => esc_html__( 'Background', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'bg_type',
			[
				'label'       => esc_html__( 'Background Type', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'image',
				'options' => [
					'image'  => __( 'Image', 'kinsley-plugin' ),
					'video' => __( 'Video', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label'       => esc_html__( 'Background Image', 'kinsley-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'bg_type' => 'image'
				]
			]
		);

		$this->add_control(
			'video',
			[
				'label'       => esc_html__( 'Video (link)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( '/video.mp4', 'kinsley-plugin' ),
				'condition' => [
					'bg_type' => 'video'
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_styling',
			[
				'label'     => esc_html__( 'Content Styling', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'stars_color',
			[
				'label'     => esc_html__( 'Stars Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-main-title .knsl-stars' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-main-title .knsl-main-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-main-title .knsl-main-title--h',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-main-title .knsl-main-title--d' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-main-title .knsl-main-title--d',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'search_styling',
			[
				'label'     => esc_html__( 'Search Styling', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'search_bg_color',
			[
				'label'     => esc_html__( 'Form BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .knsl-book-form .knsl-btn, {{WRAPPER}} .knsl-book-form .knsl-btn:focus' => 'box-shadow: 0 0 0 10px {{VALUE}}, 0 2px 48px 0 rgb(0 0 0 / 4%);',
				],
			]
		);

		$this->add_control(
			'search_color',
			[
				'label'     => esc_html__( 'Form Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'search_typography',
				'label'     => esc_html__( 'Form Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-book-form',
			]
		);

		$this->add_control(
			'search_input_bg_color',
			[
				'label'     => esc_html__( 'Form Input BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form form .nice-select, {{WRAPPER}} .knsl-book-form form input' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'search_input_color',
			[
				'label'     => esc_html__( 'Form Input Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form form .nice-select, {{WRAPPER}} .knsl-book-form form input, {{WRAPPER}} .knsl-book-form .knsl-input-frame:before' => 'color: {{VALUE}};',
					'{{WRAPPER}} .knsl-book-form .nice-select:after' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'search_button_bg_color',
			[
				'label'     => esc_html__( 'Form Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form form button.knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'search_button_color',
			[
				'label'     => esc_html__( 'Form Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-book-form form button.knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'search_button_typography',
				'label'     => esc_html__( 'Form Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-book-form form button.knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'scroll_styling',
			[
				'label'     => esc_html__( 'Scroll Styling', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'scroll_color',
			[
				'label'     => esc_html__( 'Label Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-scroll-hint-frame .knsl-white' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'scroll_typography',
				'label'     => esc_html__( 'Label Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-scroll-hint-frame .knsl-white',
			]
		);

		$this->add_control(
			'scroll_icon_color',
			[
				'label'     => esc_html__( 'Icon Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-scroll-hint-frame .knsl-scroll-hint' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .knsl-banner .knsl-banner-content .knsl-scroll-hint-frame .knsl-scroll-hint:before' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'buttons_styling',
			[
				'label'     => esc_html__( 'Buttons Styling', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'button1_bg_color',
			[
				'label'     => esc_html__( 'Button 1 BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner-buttons .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button2_bg_color',
			[
				'label'     => esc_html__( 'Button 2 BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner-buttons .knsl-btn.knsl-btn-accent-2' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner-buttons .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner-buttons .knsl-btn',
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'subtitle', 'basic' );
		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'scrolldown_text', 'basic' );
		$this->add_inline_editing_attributes( 'title_search_popup', 'basic' );
		$this->add_inline_editing_attributes( 'button_video_text', 'none' );
		$this->add_inline_editing_attributes( 'button_search_popup_text', 'none' );

		?>

		<!-- banner -->
	    <section class="knsl-banner">
	      <div class="knsl-cover-frame">
	      	<?php if ( $settings['bg_type'] == 'image' ) : ?>
	        <?php if ( $settings['image'] ) : $image = wp_get_attachment_image_url( $settings['image']['id'], 'kinsley_1920xAuto' ); ?>
	        <img src="<?php echo esc_url( $image ); ?>" alt="" class="knsl-parallax">
	        <?php endif; ?>
	        <?php else : ?>
	        <video class="knsl-parallax" muted playsinline autoplay loop>
	            <source src="<?php echo esc_url( $settings['video'] ); ?>">
	        </video>
	      	<?php endif; ?>
	      </div>
	      <div class="knsl-overlay"></div>

	      <div class="knsl-banner-content<?php if ( $settings['layout'] == 'style-2' ) : ?> knsl-p-40-0<?php endif; ?>">
	        <div class="container">
	          <?php if ( $settings['layout'] == 'style-2' ) : ?><div class="row"><div class="col-lg-8 align-self-center"><?php endif; ?>
	          <div class="knsl-main-title<?php if ( $settings['layout'] == 'style-2' ) : ?> knsl-mb-40<?php endif; ?>">
	            <div class="knsl-white">
	              <?php if ( $settings['stars'] == 'yes' ) : ?>
	              <ul class="knsl-stars<?php if ( $settings['layout'] == 'style-2' ) : ?> knsl-stars-left<?php endif; ?>">
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	              </ul>
	              <?php endif; ?>
	              <!-- main-title -->
	              <?php if ( $settings['title'] ) : ?>
	              <<?php echo esc_attr( $settings['title_tag'] ); ?> class="<?php if ( $settings['layout'] == 'style-1' || $settings['layout'] == 'style-3' ) : ?>knsl-center <?php endif; ?>knsl-mb-10 knsl-main-title--h">
	              	<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
					          	<?php echo wp_kses_post( $settings['title'] ); ?>
					        </span>
	          	  </<?php echo esc_attr( $settings['title_tag'] ); ?>>
	              <?php endif; ?>
	              <?php if ( $settings['subtitle'] ) : ?>
	              <div class="knsl-main-title--d knsl-mb-30<?php if ( $settings['layout'] == 'style-1' || $settings['layout'] == 'style-3' ) : ?> knsl-center<?php endif; ?>">
	              	<span <?php echo $this->get_render_attribute_string( 'subtitle' ); ?>>
					          	<?php echo wp_kses_post( $settings['subtitle'] ); ?>
					        </span>
	              </div>
	              <?php endif; ?>
								<?php if ( $settings['layout'] == 'style-2' ) : ?>
			          <?php if ( $settings['scrolldown'] == 'yes' ) : ?>
			          <div class="knsl-scroll-hint-frame knsl-scroll-hint-left">
			          	<?php if ( $settings['scrolldown_text'] ) : ?>
			            <div class="knsl-white knsl-mb-20">
			            	<span <?php echo $this->get_render_attribute_string( 'scrolldown_text' ); ?>>
					          	<?php echo wp_kses_post( $settings['scrolldown_text'] ); ?>
					        </span>
			            </div>
			            <?php endif; ?>
			            <a href="#knsl-triger-1" class="knsl-scroll-hint knsk-s-s"></a>
			          </div>
			          <?php endif; ?>
			          <?php endif; ?>
	            </div>
	          </div>

	          <?php if ( $settings['layout'] == 'style-2' ) : ?></div><div class="col-lg-4"><?php endif; ?>
	          <?php if ( $settings['search'] == 'yes' && ( $settings['layout'] == 'style-1' || $settings['layout'] == 'style-2' ) ) : ?>
	          <div class="knsl-book-form<?php if ( $settings['layout'] == 'style-1' || $settings['layout'] == 'style-3' ) : ?> knsl-book-form-2<?php else : ?> knsl-book-form-v<?php endif; ?>">
	            <?php echo do_shortcode( '[mphb_availability_search adults="' . $settings['adults'] . '" children="' . $settings['children'] . '" check_in_date="' . $settings['check_in_date'] . '" check_out_date="' . $settings['check_out_date'] . '" attributes="' . $settings['attributes'] . '" class="' . $settings['class'] . '"]' ); ?>
	          </div>
	          <?php endif; ?>
	          <?php if ( $settings['layout'] == 'style-2' ) : ?></div></div><?php endif; ?>
	          <?php if ( $settings['layout'] == 'style-3' ) : ?>
	          <div class="knsl-banner-buttons knsl-mb-30 knsl-center">
	            <?php if ( $settings['button_video_text'] ) : ?>
	            <a data-magnific-video href="https://www.youtube.com/watch?v=<?php echo esc_attr( $settings['video_id'] ); ?>" class="knsl-btn knsl-transparent-border">
	            	<span class="img-svg img-svg-play knsl-zoom"></span>
	            	<span <?php echo $this->get_render_attribute_string( 'button_video_text' ); ?>>
  			          	<?php echo wp_kses_post( $settings['button_video_text'] ); ?>
  			        </span>
	            </a>
	            <?php endif; ?>
	            <?php if ( $settings['button_search_popup_text'] ) : ?>
	            <a href="#" class="knsl-btn knsl-btn-book knsl-transparent-border knsl-btn-accent-2">
	            	<span class="img-svg img-svg-bookmark"></span>
	            	<span <?php echo $this->get_render_attribute_string( 'button_search_popup_text' ); ?>>
  			          	<?php echo wp_kses_post( $settings['button_search_popup_text'] ); ?>
  			        </span>
	            </a>
	            <?php endif; ?>
	          </div>
	          <?php endif; ?>
	          <?php if ( $settings['layout'] == 'style-1' || $settings['layout'] == 'style-3' ) : ?>
	          <?php if ( $settings['scrolldown'] == 'yes' ) : ?>
	          <div class="knsl-scroll-hint-frame">
	          	<?php if ( $settings['scrolldown_text'] ) : ?>
	            <div class="knsl-white knsl-mb-20">
	            	<span <?php echo $this->get_render_attribute_string( 'scrolldown_text' ); ?>>
			          	<?php echo wp_kses_post( $settings['scrolldown_text'] ); ?>
			        </span>
	            </div>
	            <?php endif; ?>
	            <a href="#knsl-triger-1" class="knsl-scroll-hint knsk-s-s"></a>
	          </div>
	          <?php endif; ?>
	          <?php endif; ?>
	        </div>
	      </div>
	    </section>
	    <!-- banner end -->

	    <?php if ( $settings['layout'] == 'style-3' ) : ?>
	    <!-- popup -->
	    <div class="knsl-popup-frame knsl-popup-frame-1">
	      <div class="knsl-book-form knsl-book-form-v knsl-book-popup">
	        <span class="knsl-close-popup">+</span>
	        <?php if ( $settings['title_search_popup'] ) : ?>
	        <h2 class="knsl-mb-40">
	        	<span <?php echo $this->get_render_attribute_string( 'title_search_popup' ); ?>>
		          	<?php echo wp_kses_post( $settings['title_search_popup'] ); ?>
		        </span>
	        </h2>
	        <?php endif; ?>

	        <?php echo do_shortcode( '[mphb_availability_search adults="' . $settings['adults'] . '" children="' . $settings['children'] . '" check_in_date="' . $settings['check_in_date'] . '" check_out_date="' . $settings['check_out_date'] . '" attributes="' . $settings['attributes'] . '" class="' . $settings['class'] . '"]' ); ?>

	      </div>
	    </div>
	    <!-- popup end -->
	    <?php endif; ?>

		<?php
	}

	/**
	 * Render widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template() {
		?>

		<#
		view.addInlineEditingAttributes( 'subtitle', 'basic' );
		view.addInlineEditingAttributes( 'title', 'basic' );
		view.addInlineEditingAttributes( 'scrolldown_text', 'basic' );
		view.addInlineEditingAttributes( 'title_search_popup', 'basic' );
		view.addInlineEditingAttributes( 'button_video_text', 'none' );
		view.addInlineEditingAttributes( 'button_search_popup_text', 'none' );
		#>

		<!-- banner -->
	    <section class="knsl-banner">
	      <div class="knsl-cover-frame">
	      	<# if ( settings.bg_type == 'image' ) { #>
	        <# if ( settings.image ) { #>
	        <img src="{{{ settings.image.url }}}" alt="" class="knsl-parallax">
	        <# } #>
	        <# } else { #>
	        <video class="knsl-parallax" muted playsinline autoplay loop>
	            <source src="{{{ settings.video }}}">
	        </video>
	      	<# } #>
	      </div>
	      <div class="knsl-overlay"></div>

	      <div class="knsl-banner-content<# if ( settings.layout == 'style-2' ) { #> knsl-p-40-0<# } #>">
	        <div class="container">
	          <# if ( settings.layout == 'style-2' ) { #><div class="row"><div class="col-lg-8 align-self-center"><# } #>
	          <div class="knsl-main-title<# if ( settings.layout == 'style-2' ) { #> knsl-mb-40<# } #>">
	            <div class="knsl-white">
	              <# if ( settings.stars == 'yes' ) { #>
	              <ul class="knsl-stars<# if ( settings.layout == 'style-2' ) { #> knsl-stars-left<# } #>">
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	                <li><i class="fas fa-star"></i></li>
	              </ul>
	              <# } #>
	              <!-- main-title -->
	              <# if ( settings.title ) { #>
	              <{{{ settings.title_tag }}} class="<# if ( settings.layout == 'style-1' || settings.layout == 'style-3' ) { #>knsl-center <# } #>knsl-mb-10 knsl-main-title--h">
			        <span {{{ view.getRenderAttributeString( 'title' ) }}}>
			          	{{{ settings.title }}}
			        </span>
	          	  </{{{ settings.title_tag }}}>
	              <# } #>
	              <# if ( settings.subtitle ) { #>
	              <div class="knsl-main-title--d knsl-mb-30<# if ( settings.layout == 'style-1' || settings.layout == 'style-3' ) { #> knsl-center<# } #>">
			        <span {{{ view.getRenderAttributeString( 'subtitle' ) }}}>
			          	{{{ settings.subtitle }}}
			        </span>
	              </div>
	              <# } #>
	            </div>
	          </div>
	          <# if ( settings.layout == 'style-2' ) { #>
	          <# if ( settings.scrolldown == 'yes' ) { #>
	          <div class="knsl-scroll-hint-frame knsl-scroll-hint-left">
	          	<# if ( settings.scrolldown_text ) { #>
	            <div class="knsl-white knsl-mb-20">
			        <span {{{ view.getRenderAttributeString( 'scrolldown_text' ) }}}>
			          	{{{ settings.scrolldown_text }}}
			        </span>
	            </div>
	            <# } #>
	            <a href="#knsl-triger-1" class="knsl-scroll-hint knsk-s-s"></a>
	          </div>
	          <# } #>
	          <# } #>
	          <# if ( settings.layout == 'style-2' ) { #></div><div class="col-lg-4"><# } #>
	          <# if ( settings.search == 'yes' && ( settings.layout == 'style-1' || settings.layout == 'style-2' ) ) { #>
	          <div class="knsl-book-form<# if ( settings.layout == 'style-1' || settings.layout == 'style-2' ) { #> knsl-book-form-2<# } else { #> knsl-book-form-v<# } #>">
	            [mphb_availability_search adults="{{{ settings.adults }}}" children="{{{ settings.children }}}" check_in_date="{{{ settings.check_in_date }}}" check_out_date="{{{ settings.check_out_date }}}" attributes="{{{ settings.attributes }}}" class="{{{ settings.class }}}"]
	          </div>
	          <# } #>
	          <# if ( settings.layout == 'style-2' ) { #></div></div><# } #>
	          <# if ( settings.layout == 'style-3' ) { #>
	          <div class="knsl-banner-buttons knsl-mb-30 knsl-center">
	            <# if ( settings.button_video_text ) { #>
	            <a data-magnific-video href="https://www.youtube.com/watch?v={{{ settings.video_id }}}" class="knsl-btn knsl-transparent-border">
	            	<span class="img-svg img-svg-play knsl-zoom"></span>
			        <span {{{ view.getRenderAttributeString( 'button_video_text' ) }}}>
			          	{{{ settings.button_video_text }}}
			        </span>
	            </a>
	            <# } #>
	            <# if ( settings.button_search_popup_text ) { #>
	            <a id="book-popup-2" class="knsl-btn knsl-transparent-border knsl-btn-accent-2">
	            	<span class="img-svg img-svg-bookmark"></span>
			        <span {{{ view.getRenderAttributeString( 'button_search_popup_text' ) }}}>
			          	{{{ settings.button_search_popup_text }}}
			        </span>
	            </a>
	            <# } #>
	          </div>
	          <# } #>
	          <# if ( settings.layout == 'style-1' || settings.layout == 'style-3' ) { #>
	          <# if ( settings.scrolldown == 'yes' ) { #>
	          <div class="knsl-scroll-hint-frame">
	          	<# if ( settings.scrolldown_text ) { #>
	            <div class="knsl-white knsl-mb-20">
			        <span {{{ view.getRenderAttributeString( 'scrolldown_text' ) }}}>
			          	{{{ settings.scrolldown_text }}}
			        </span>
	            </div>
	            <# } #>
	            <a href="#knsl-triger-1" class="knsl-scroll-hint knsk-s-s"></a>
	          </div>
	          <# } #>
	          <# } #>
	        </div>
	      </div>
	    </section>
	    <!-- banner end -->

	    <# if ( settings.layout == 'style-3' ) { #>
	    <!-- popup -->
	    <div class="knsl-popup-frame">
	      <div class="knsl-book-form knsl-book-form-v knsl-book-popup">
	        <span class="knsl-close-popup">+</span>
	        <# if ( settings.title_search_popup ) { #>
	        <h2 class="knsl-mb-40">
		        <span {{{ view.getRenderAttributeString( 'title_search_popup' ) }}}>
		          	{{{ settings.title_search_popup }}}
		        </span>
	        </h2>
	        <# } #>

	        [mphb_availability_search adults="{{{ settings.adults }}}" children="{{{ settings.children }}}" check_in_date="{{{ settings.check_in_date }}}" check_out_date="{{{ settings.check_out_date }}}" attributes="{{{ settings.attributes }}}" class="{{{ settings.class }}}"]

	      </div>
	    </div>
	    <!-- popup end -->
	    <# } #>

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Hero_Banner_Widget() );
