<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Intro Widget.
 *
 * @since 1.0
 */
class Kinsley_Intro_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-intro';
	}

	public function get_title() {
		return esc_html__( 'Intro', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'breadcrumbs_tab',
			[
				'label' => esc_html__( 'Breadcrumbs', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'breadcrumbs',
			[
				'label'       => esc_html__( 'Breadcrumbs', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'kinsley-plugin' ),
				'label_off' => __( 'No', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner-simple .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner-simple .knsl-title--h',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-banner-simple .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-banner-simple .knsl-text',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'breadcrumbs_styling',
			[
				'label'     => esc_html__( 'Breadcrumbs', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'breadcrumbs_bgcolor',
			[
				'label'     => esc_html__( 'Background Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-breadcrumbs' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'breadcrumbs_link_color',
			[
				'label'     => esc_html__( 'Background Link Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-breadcrumbs li a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'breadcrumbs_link_typography',
				'label'     => esc_html__( 'Background Link Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-breadcrumbs li',
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );

		$page_id = get_the_ID();

		?>

    <!-- banner -->
    <section class="knsl-banner-simple knsl-transition-bottom">
      <?php kinsley_deco_svg( 'both' ); ?>

      <div class="container">
        <div class="row">
          <div class="col-lg-12">

            <div class="knsl-center knsl-title-frame">
              <?php if ( $settings['title'] ) : ?>
              <<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20 knsl-h1-inner">
                <span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
                    <?php echo wp_kses_post( $settings['title'] ); ?>
                </span>
              </<?php echo esc_attr( $settings['title_tag'] ); ?>>
              <?php endif; ?>
              <?php if ( $settings['description'] ) : ?>
              <p class="knsl-text knsl-mb-30">
                <span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
                    <?php echo wp_kses_post( $settings['description'] ); ?>
                </span>
              </p>
              <?php endif; ?>

              <?php if ( $settings['breadcrumbs'] == 'yes' ) : kinsley_breadcrumbs( $page_id ); endif; ?>

            </div>

          </div>
        </div>
      </div>
    </section>
    <!-- banner end -->

		<?php
	}

	/**
	 * Render widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template() {
		?>

		<#
		view.addInlineEditingAttributes( 'title', 'basic' );
		view.addInlineEditingAttributes( 'description', 'basic' );
		#>

    <!-- banner -->
    <section class="knsl-banner-simple knsl-transition-bottom">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">

            <div class="knsl-center knsl-title-frame">
              <# if ( settings.title ) { #>
              <{{{ settings.title_tag }}} class="knsl-title--h knsl-mb-20 knsl-h1-inner">
                <span {{{ view.getRenderAttributeString( 'title' ) }}}>
                    {{{ settings.title }}}
                </span>
              </{{{ settings.title_tag }}}>
              <# } #>
              <# if ( settings.description ) { #>
              <p class="knsl-text knsl-mb-30">
                <span {{{ view.getRenderAttributeString( 'description' ) }}}>
				          	{{{ settings.description }}}
				        </span>
              </p>
              <# } #>
              <# if ( settings.breadcrumbs == 'yes' ) { #>
              <ul class="knsl-breadcrumbs">
                <li><a href="#">Home</a></li>
                <li><span>About</span></li>
              </ul>
              <# } #>
            </div>

          </div>
        </div>
      </div>
    </section>
    <!-- banner end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Intro_Widget() );
