<?php

namespace Elementor;

use \Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Availability Calendar Widget.
 *
 * @since 1.0
 */
class Kinsley_MPHB_Availability_Calendar_Widget extends Kinsley_MPHB_AbstractCalendarWidget
{
  public function get_name() {
    return 'kinsley-availability-calendar';
  }

  public function get_title() {
    return esc_html__( 'Room / Availability Calendar', 'kinsley-plugin' );
  }

  public function get_icon() {
    return 'eicon-parallax';
  }

  public function get_categories() {
    return [ 'kinsley-category' ];
  }

  /**
   * Register widget controls.
   *
   * @since 1.0
   */
  protected function register_controls()
  {
        $this->start_controls_section('section_parameters', array(
            'label'       => __('Parameters', 'kinsley-plugin')
        ));

        $this->add_control(
    			'title',
    			[
    				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
    				'type'        => Controls_Manager::TEXTAREA,
    				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
    				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
    			]
    		);

        $this->add_control(
    			'source_id',
    			[
    				'label'       => esc_html__( 'Parse from', 'kinsley-plugin' ),
    				'type'        => Controls_Manager::SELECT,
    				'default' => 'custom',
    				'options' => [
    					'custom'  => __( 'Custom ID', 'kinsley-plugin' ),
    					'current' => __( 'Current ID', 'kinsley-plugin' ),
    				],
    			]
    		);

        // "id" required, but it will cause Backbone error "A "url" property or function must be specified"
        $this->add_control('type_id', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('ID', 'kinsley-plugin'),
            'description' => __('ID of accommodation type.', 'kinsley-plugin'),
            'default'     => '',
            'condition'   => [
                'source_id' => 'custom',
            ]
        ));

        $this->add_control('monthstoshow', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('How many months to show', 'kinsley-plugin'),
            'description' => __('Set the number of columns or the number of rows and columns separated by comma. Example: "3" or "2,3"', 'kinsley-plugin'),
            'default'     => '2'
        ));

        $this->add_control('class', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Class', 'kinsley-plugin'),
            'description' => __('Custom CSS class for shortcode wrapper.', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->end_controls_section();

        $this->start_controls_section(
    			'content_styling',
    			[
    				'label'     => esc_html__( 'Styling', 'kinsley-plugin' ),
    				'tab'       => Controls_Manager::TAB_STYLE,
    			]
    		);

    		$this->add_control(
    			'title_color',
    			[
    				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
    				'type'      => Controls_Manager::COLOR,
    				'default'	=> '',
    				'selectors' => [
    					'{{WRAPPER}} .row h3' => 'color: {{VALUE}};',
    				],
    			]
    		);

    		$this->add_group_control(
    			Group_Control_Typography::get_type(),
    			[
    				'name'     => 'title_typography',
    				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
    				'selector' => '{{WRAPPER}} .row h3',
    			]
    		);

    		$this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     */
    protected function render()
    {

        $atts = $this->get_settings();
        $atts['id'] = $atts['type_id'];
        $atts['class'] .= ' knsl-scroll-animation';

        $current_id = get_the_ID();

        if ( $atts['source_id'] == 'current' ) {
          $atts['id'] = $current_id;
          $atts['type_id'] = $current_id;
        }

        $this->add_inline_editing_attributes( 'title', 'basic' );

        ?>

        <?php if ( $atts['title'] ) : ?>
				<div class="col-lg-12">
					<h3 class="knsl-mb-40 knsl-scroll-animation">
						<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
								<?php echo wp_kses_post( $atts['title'] ); ?>
						</span>
					</h3>
				</div>
				<?php endif; ?>

        <?php
        do_action('mphbe_before_availability_calendar_widget_render', $atts);

        $shortcode = MPHB()->getShortcodes()->getAvailabilityCalendar();
        echo $shortcode->render($atts, null, $shortcode->getName()); // phpcs:ignore
        parent::render();

        do_action('mphbe_after_availability_calendar_widget_render', $atts);

    }
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_MPHB_Availability_Calendar_Widget() );
