<?php

namespace Elementor;

use \Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Availability Form Widget.
 *
 * @since 1.0
 */
class Kinsley_MPHB_Availability_Form_Widget extends Kinsley_MPHB_AbstractWidget
{
    public function get_name() {
      return 'kinsley-availability-form';
    }

    public function get_title() {
      return esc_html__( 'Room / Booking Form', 'kinsley-plugin' );
    }

    public function get_icon() {
      return 'eicon-parallax';
    }

    public function get_categories() {
      return [ 'kinsley-category' ];
    }

    /**
  	 * Register widget controls.
  	 *
  	 * @since 1.0
  	 */
    protected function register_controls()
    {
        $this->start_controls_section('section_parameters', array(
            'label'       => __('Parameters', 'kinsley-plugin')
        ));

        $this->add_control(
    			'layout',
    			[
    				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
    				'type'        => Controls_Manager::SELECT,
    				'default' => 'vertical',
    				'options' => [
    					'vertical'  => __( 'Vertical', 'kinsley-plugin' ),
    					'horizontal' => __( 'Horizontal', 'kinsley-plugin' ),
    				],
    			]
    		);

        $this->add_control(
    			'source_id',
    			[
    				'label'       => esc_html__( 'Parse from', 'kinsley-plugin' ),
    				'type'        => Controls_Manager::SELECT,
    				'default' => 'custom',
    				'options' => [
    					'custom'  => __( 'Custom ID', 'kinsley-plugin' ),
    					'current' => __( 'Current ID', 'kinsley-plugin' ),
    				],
    			]
    		);

        // "id" required, but it will cause Backbone error "A "url" property or function must be specified"
        $this->add_control('type_id', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('ID', 'kinsley-plugin'),
            'description' => __('ID of Accommodation Type to check availability.', 'kinsley-plugin'),
            'default'     => '',
            'condition'   => [
                'source_id' => 'custom',
            ]
        ));

        $this->add_control(
    			'sticky',
    			[
    				'label'       => esc_html__( 'Sticky', 'kinsley-plugin' ),
    				'type' => Controls_Manager::SWITCHER,
    				'label_on' => __( 'Yes', 'kinsley-plugin' ),
    				'label_off' => __( 'No', 'kinsley-plugin' ),
    				'return_value' => 'yes',
    				'default' => 'no',
    			]
    		);

        $this->add_control('sticky_offset_top', array(
            'type'        => Controls_Manager::NUMBER,
            'label'       => __('Sticky Offset Top', 'kinsley-plugin'),
            'default'     => 100,
            'condition' => [
                'sticky' => 'yes',
            ]
        ));

        $this->add_control('class', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Class', 'kinsley-plugin'),
            'description' => __('Custom CSS class for shortcode wrapper.', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->end_controls_section();
    }

    /**
     * Render widget output on the frontend.
     *
     * @since 1.0
     */
    protected function render()
    {
        $atts = $this->get_settings();

        $atts['id']     = $atts[ 'type_id' ];

        $current_id = get_the_ID();

        if ( $atts['source_id'] == 'current' ) {
          $atts['id'] = $current_id;
          $atts['type_id'] = $current_id;
        }

        $className = ! empty( $atts[ 'class' ] ) ? $atts[ 'class' ] : '';

        $atts['class']  = ! empty( $atts[ 'widget_styles' ] ) ? $atts[ 'widget_styles' ] : '';
        $atts['class'] .= ! empty( $atts[ 'hide_labels' ] ) ? $atts[ 'hide_labels' ] === 'yes' ? 'mphbs-hide-labels ' : '' : '';
        $atts['class'] .= ! empty( $atts[ 'no_paddings' ] ) ? $atts[ 'no_paddings' ] === 'yes' ? 'mphbs-no-paddings ' : '' : '';
        $atts['class'] .= ! empty( $atts[ 'hide_tips' ] ) ? $atts[ 'hide_tips' ] === 'yes' ? 'mphbs-hide-rf-tip ' : '' : '';
        $atts['class'] .= ! empty( $atts[ 'stretch_btn' ] ) ? $atts[ 'stretch_btn' ] === 'yes' ? 'mphbs-fluid-button ' : '' : '';
        $atts['class'] .= ! empty( $atts[ 'fields_width' ] ) ? $atts[ 'fields_width' ] : '';
        $atts['class'] .= $className;

        if ( $atts['layout'] == 'vertical' ) {
          $atts['class'] .= ' knsl-book-form knsl-book-form-v';
        }
        if ( $atts['layout'] == 'horizontal' ) {
          $atts['class'] .= ' knsl-book-form';
        }
        ?>
        <?php if ( $atts['sticky'] == 'yes' ) : ?>
        <div class="knsl-sticky knsl-stycky-right" data-margin-top="<?php echo esc_attr( $atts['sticky_offset_top'] ); ?>">
        <?php endif; ?>
        <?php
        do_action('mphbe_before_availability_widget_render', $atts);

        $shortcode = MPHB()->getShortcodes()->getBookingForm();
        echo $shortcode->render($atts, null, $shortcode->getName()); // phpcs:ignore

        do_action('mphbe_after_availability_widget_render', $atts);
        ?>
        <?php if ( $atts['sticky'] == 'yes' ) : ?>
        </div>
        <?php endif; ?>
        <?php
    }
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_MPHB_Availability_Form_Widget() );
