<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Room Amenties Widget.
 *
 * @since 1.0
 */
class Kinsley_Room_Amenity_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-room-amenity';
	}

	public function get_title() {
		return esc_html__( 'Room / Amenties', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_tab',
			[
				'label' => esc_html__( 'Content', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Parse from', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'plugin',
				'options' => [
					'plugin'  => __( 'Plugin', 'kinsley-plugin' ),
					//'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_styling',
			[
				'label'     => esc_html__( 'Content Styles', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .row h3' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .row h3',
			]
		);

		$this->add_control(
			'item_name_color',
			[
				'label'     => esc_html__( 'Item Name Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-icon-box h5' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_name_typography',
				'label'     => esc_html__( 'Item Name Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-icon-box h5',
			]
		);

		$this->add_control(
			'item_bgcolor',
			[
				'label'     => esc_html__( 'Item Background Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-icon-box.knsl-icon-box-sm' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );

		$room_id = get_the_ID();

		$amenities = get_the_terms( $room_id, 'mphb_room_type_facility' );

		?>

		<!-- features -->
		<section class="knsl-mb-60">
			<div class="row">
				<?php if ( $settings['title'] ) : ?>
				<div class="col-lg-12">
					<h3 class="knsl-mb-40 knsl-scroll-animation">
						<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
								<?php echo wp_kses_post( $settings['title'] ); ?>
						</span>
					</h3>
				</div>
				<?php endif; ?>
				<?php if ( $amenities ) : ?>
				<?php foreach ( $amenities as $item ) : ?>
				<div class="col-6 col-md-3">

					<!-- icon box -->
					<div class="knsl-icon-box knsl-icon-box-sm knsl-scroll-animation">
						<?php $icon = get_field( 'icon', 'mphb_room_type_facility_' . $item->term_id ); ?>
						<a href="<?php echo esc_url( get_term_link( $item->term_id ) ); ?>">
							<img src="<?php echo esc_url( $icon ); ?>" alt="<?php echo esc_attr( $item->name ); ?>" class="knsl-mb-10" />
							<h5><?php echo esc_html( $item->name ); ?></h5>
						</a>
					</div>
					<!-- icon box end -->

				</div>
				<?php endforeach; ?>
				<?php endif; ?>
			</div>
		</section>
		<!-- features end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Room_Amenity_Widget() );
