<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Room Attributes Widget.
 *
 * @since 1.0
 */
class Kinsley_Room_Attributes_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-room-attributes';
	}

	public function get_title() {
		return esc_html__( 'Room / Attributes', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_tab',
			[
				'label' => esc_html__( 'Content', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Parse from', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'plugin',
				'options' => [
					'plugin'  => __( 'Plugin', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'capacity',
			[
				'label'       => esc_html__( 'Capacity', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'children',
			[
				'label'       => esc_html__( 'Children', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'size',
			[
				'label'       => esc_html__( 'Size', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'bed_type',
			[
				'label'       => esc_html__( 'Bed Type', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'view',
			[
				'label'       => esc_html__( 'View', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'categories',
			[
				'label'       => esc_html__( 'Categories', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'facilities',
			[
				'label'       => esc_html__( 'Facilities', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$this->add_control(
			'custom_attribute',
			[
				'label'       => esc_html__( 'Custom Attribute', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition'   => [
          'source'  => 'plugin',
        ],
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'icon', [
				'label' => esc_html__( 'Image', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
			]
		);

		$repeater->add_control(
			'title', [
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$repeater->add_control(
			'value', [
				'label'       => esc_html__( 'Value', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter value', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Value', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'items',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'prevent_empty' => false,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ title }}}',
				'condition'   => [
          'source'  => 'custom',
        ],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_styling',
			[
				'label'     => esc_html__( 'Styling', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_bgcolor',
			[
				'label'     => esc_html__( 'Background Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-room-features-lg' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-room-features-lg .mphb-single-room-type-attributes li' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_typography',
				'label'     => esc_html__( 'Text Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-room-features-lg .mphb-single-room-type-attributes li',
			]
		);

		$this->add_control(
			'item_icon_bgcolor',
			[
				'label'     => esc_html__( 'Item Icon BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-room-features-lg .mphb-single-room-type-attributes li:after' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$atts_classes = '';

		if ( $settings['capacity'] == 'yes' ) {
			$atts_classes .= ' show-capacity';
		}
		if ( $settings['size'] == 'yes' ) {
			$atts_classes .= ' show-size';
		}
		if ( $settings['facilities'] == 'yes' ) {
			$atts_classes .= ' show-facilities';
		}
		if ( $settings['view'] == 'yes' ) {
			$atts_classes .= ' show-view';
		}
		if ( $settings['categories'] == 'yes' ) {
			$atts_classes .= ' show-categories';
		}
		if ( $settings['bed_type'] == 'yes' ) {
			$atts_classes .= ' show-bed-type';
		}
		if ( $settings['custom_attribute'] == 'yes' ) {
			$atts_classes .= ' show-custom-attribute';
		}
		if ( $settings['children'] == 'yes' ) {
			$atts_classes .= ' show-children';
		}

		?>

		<!-- room info -->
		<div class="knsl-room-features-lg knsl-mb-20<?php echo esc_attr( $atts_classes ); ?>">
			<?php if ( $settings['source'] == 'custom' ) : ?>
			<?php if ( $settings['items'] ) : ?>
			<?php foreach ( $settings['items'] as $index => $item ) :
				$item_value = $this->get_repeater_setting_key( 'value', 'items', $index );
				$this->add_inline_editing_attributes( $item_value, 'none' );
			?>
			<div class="knsl-feature" title="<?php echo esc_attr( $item['title'] ); ?>">
				<div class="knsl-icon-frame">
					<?php \Elementor\Icons_Manager::render_icon( $item['icon'], [ 'aria-hidden' => 'true' ] ); ?>
				</div>
				<span>
					<span <?php echo $this->get_render_attribute_string( $item_value ); ?>>
						<?php echo wp_kses_post( $item['value'] ); ?>
					</span>
				</span>
			</div>
			<?php endforeach; ?>
			<?php endif; ?>
			<?php else :
				kinsley_mphb_room_getAttributes();
			endif; ?>
		</div>
		<!-- room info end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Room_Attributes_Widget() );
