<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Room Price Widget.
 *
 * @since 1.0
 */
class Kinsley_Room_Price_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-room-price';
	}

	public function get_title() {
		return esc_html__( 'Room / Price', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_tab',
			[
				'label' => esc_html__( 'Content', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Parse from', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'plugin',
				'options' => [
					'plugin'  => __( 'Plugin', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'price',
			[
				'label'       => esc_html__( 'Price', 'kinsley-plugin' ),
        'label_block' => true,
				'type'        => Controls_Manager::TEXT,
        'placeholder' => esc_html__( '$199', 'kinsley-plugin' ),
				'default'     => esc_html__( '$0', 'kinsley-plugin' ),
        'condition'   => [
          'source'  => 'custom',
        ],
			]
		);

    $this->add_control(
			'price_after',
			[
				'label'       => esc_html__( 'Price (After)', 'kinsley-plugin' ),
        'label_block' => true,
				'type'        => Controls_Manager::TEXT,
        'placeholder' => esc_html__( '/ per night', 'kinsley-plugin' ),
				'default'     => esc_html__( '/ per night', 'kinsley-plugin' ),
        'condition'   => [
          'source'  => 'custom',
        ],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'content_styling',
			[
				'label'     => esc_html__( 'Content Styles', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'price_color',
			[
				'label'     => esc_html__( 'Price Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-price-card .knsl-price-number' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_typography',
				'label'     => esc_html__( 'Price Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-price-card .knsl-price-number',
			]
		);

		$this->add_control(
			'price_after_color',
			[
				'label'     => esc_html__( 'Price After Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-price-card .knsl-price-number .knsl-price-number-after, {{WRAPPER}} .knsl-price-card .knsl-price-number .mphb-price-period' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'price_after_typography',
				'label'     => esc_html__( 'Price After Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-price-card .knsl-price-number .knsl-price-number-after, {{WRAPPER}} .knsl-price-card .knsl-price-number .mphb-price-period',
			]
		);

		$this->add_control(
			'item_bgcolor',
			[
				'label'     => esc_html__( 'Item Background Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-price-card' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'price', 'none' );
		$this->add_inline_editing_attributes( 'price_after', 'none' );

		?>

    <div class="knsl-price-card knsl-mb-20">
      <div class="knsl-price-number">
        <?php if ( $settings['source'] == 'custom' ) : ?>
        <span <?php echo $this->get_render_attribute_string( 'price' ); ?>>
  				<?php echo wp_kses_post( $settings['price'] ); ?>
  			</span>
        <span class="knsl-price-number-after">
          <span <?php echo $this->get_render_attribute_string( 'price_after' ); ?>>
    				<?php echo wp_kses_post( $settings['price_after'] ); ?>
    			</span>
        </span>
        <?php else :
          kinsley_mphb_room_getPrice();
        endif; ?>
      </div>
    </div>

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Room_Price_Widget() );
