<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Rooms Carousel Widget.
 *
 * @since 1.0
 */
class Kinsley_Rooms_Carousel_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-rooms-carousel';
	}

	public function get_title() {
		return esc_html__( 'Rooms (Carousel)', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

    $this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'categories' => __( 'Categories', 'kinsley-plugin' ),
					'tags' => __( 'Tags', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
					'not_current' => __( 'Not current', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_categories',
			[
				'label'       => esc_html__( 'Categories', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_categories(),
				'condition' => [
            'source' => 'categories'
        ],
			]
		);

		$this->add_control(
			'source_tags',
			[
				'label'       => esc_html__( 'Tags', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_tags(),
				'condition' => [
            'source' => 'tags'
        ],
			]
		);

		$this->add_control(
			'source_custom',
			[
				'label'       => esc_html__( 'Custom Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_custom(),
				'condition' => [
            'source' => 'custom'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 4,
				'default'     => 4,
			]
		);

		$this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'menu_order',
				'options' => [
					'none'           => __('No order', 'kinsley-plugin'),
					'ID'             => __('Post ID', 'kinsley-plugin'),
					'author'         => __('Post author', 'kinsley-plugin'),
					'title'          => __('Post title', 'kinsley-plugin'),
					'name'           => __('Post name (post slug)', 'kinsley-plugin'),
					'date'           => __('Post date', 'kinsley-plugin'),
					'modified'       => __('Last modified date', 'kinsley-plugin'),
					'parent'         => __('Parent ID', 'kinsley-plugin'),
					'rand'           => __('Random order', 'kinsley-plugin'),
					'comment_count'  => __('Number of comments', 'kinsley-plugin'),
					'relevance'      => __('Relevance', 'kinsley-plugin'),
					'menu_order'     => __('Page order', 'kinsley-plugin'),
					'meta_value'     => __('Meta value', 'kinsley-plugin'),
					'meta_value_num' => __('Numeric meta value', 'kinsley-plugin'),
					'post__in'       => __('Price', 'kinsley-plugin')
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC'            => __('Ascending (1, 2, 3)', 'kinsley-plugin'),
					'DESC'           => __('Descending (3, 2, 1)', 'kinsley-plugin')
				],
			]
		);

		$this->end_controls_section();

    $this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'bg_position',
			[
				'label'       => esc_html__( 'BG Transition Position', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'top'  => __( 'Top', 'kinsley-plugin' ),
					'bottom' => __( 'Bottom', 'kinsley-plugin' ),
          'middle' => __( 'Middle', 'kinsley-plugin' ),
          'none' => __( 'None', 'kinsley-plugin' ),
				],
			]
		);

    $this->add_control('attr_title', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Title', 'kinsley-plugin'),
        'description' => __('Whether to display title of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_featured_image', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Featured image', 'kinsley-plugin'),
        'description' => __('Whether to display featured image of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_gallery', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Gallery', 'kinsley-plugin'),
        'description' => __('Whether to display gallery of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_excerpt', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Excerpt', 'kinsley-plugin'),
        'description' => __('Whether to display excerpt (short description) of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Details', 'kinsley-plugin'),
        'description' => __('Whether to display details of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_capacity', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - capacity', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_children', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - children', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_amenity', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - amenities', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_size', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - size', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_category', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - categories', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_attributes', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - attributes', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_view', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - view', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_bed_type', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - bed type', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_price', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Price', 'kinsley-plugin'),
        'description' => __('Whether to display price of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_view_button', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('View Button', 'kinsley-plugin'),
        'description' => __('Whether to display "View Details" button with the link to accommodation type.', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_book_button', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Book Button', 'kinsley-plugin'),
        'description' => __('Whether to display "Book" button.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->end_controls_section();

    $this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'item_bg_color',
			[
				'label'     => esc_html__( 'Item BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_details_bgcolor',
			[
				'label'     => esc_html__( 'Details BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_details_color',
			[
				'label'     => esc_html__( 'Details Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_details_typography',
				'label'     => esc_html__( 'Details Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes',
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type h2 a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type h2',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .knsl-text-light' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .knsl-text-light',
			]
		);

    $this->add_control(
			'item_price_color',
			[
				'label'     => esc_html__( 'Price Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_typography',
				'label'     => esc_html__( 'Price Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-price',
			]
		);

    $this->add_control(
			'item_price_after_color',
			[
				'label'     => esc_html__( 'Price After Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-price-period' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_after_typography',
				'label'     => esc_html__( 'Price After Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-price-period',
			]
		);

    $this->add_control(
			'item_btn_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-book-button' => 'color: {{VALUE}};',
				],
			]
		);

    $this->add_control(
			'item_btn_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-book-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_btn_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-book-button',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Categories List.
	 *
	 * @since 1.0
	 */
	protected function get_rooms_categories() {
		$categories = [];

		$args = array(
			'type'			=> 'mphb_room_type',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'DESC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'mphb_room_type_category',
			'pad_counts'	=> false
		);

		$rooms_categories = get_categories( $args );

		foreach ( $rooms_categories as $category ) {
			$categories[$category->term_id] = $category->name;
		}

		return $categories;
	}

	protected function get_rooms_tags() {
		$tags = [];

		$args = array(
			'type'			=> 'mphb_room_type',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'DESC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'mphb_room_type_tag',
			'pad_counts'	=> false
		);

		$rooms_tags = get_categories( $args );

		foreach ( $rooms_tags as $tag ) {
			$tags[$tag->term_id] = $tag->name;
		}

		return $tags;
	}

	protected function get_rooms_custom() {
		$items = [];

		$args = array(
			'post_type'			=> 'mphb_room_type',
			'post_status'		=> 'publish',
			'posts_per_page'	=> -1
		);

		$rooms_items = new \WP_Query( $args );

		while ( $rooms_items->have_posts() ) : $rooms_items->the_post();
			$items[get_the_ID()] = get_the_title();
		endwhile; wp_reset_postdata();

		return $items;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

    $this->add_inline_editing_attributes( 'more', 'none' );
		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );

		$current_id = get_the_ID();
		$ids = '';

		if ( $settings['source'] == 'categories' ) {
			$ids = $settings['source_categories'];
		} elseif ( $settings['source'] == 'tags' ) {
			$ids = $settings['source_tags'];
		} elseif ( $settings['source'] == 'custom' ) {
			$ids = $settings['source_custom'];
		} else {}

		$args = array(
			'post_type'			=> 'mphb_room_type',
			'post_status'		=> 'publish',
			'orderby'			=> $settings['sort'],
			'order'				=> $settings['order'],
			'posts_per_page'	=> $settings['limit']
		);

		if ( $settings['source'] == 'categories' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'mphb_room_type_category',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'tags' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'mphb_room_type_tag',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'custom' ) {
			$args += array( 'post__in' => $ids );
		}
		if ( $settings['source'] == 'not_current' ) {
			$args += array( 'post__not_in' => array( $current_id ) );
		}

    $attr_classes = '';

    if ( $settings['attr_details_capacity'] == 'false' ) {
      $attr_classes .= ' attr-details-capacity-false';
    }
    if ( $settings['attr_details_size'] == 'false' ) {
      $attr_classes .= ' attr-details-size-false';
    }
    if ( $settings['attr_details_amenity'] == 'false' ) {
      $attr_classes .= ' attr-details-amenity-false';
    }
    if ( $settings['attr_details_category'] == 'false' ) {
      $attr_classes .= ' attr-details-category-false';
    }
    if ( $settings['attr_details_attributes'] == 'false' ) {
      $attr_classes .= ' attr-details-attributes-false';
    }
		if ( $settings['attr_details_view'] == 'false' ) {
      $attr_classes .= ' attr-details-view-false';
    }
		if ( $settings['attr_details_bed_type'] == 'false' ) {
      $attr_classes .= ' attr-details-bed-type-false';
    }
		if ( $settings['attr_details_children'] == 'false' ) {
      $attr_classes .= ' attr-details-children-false';
    }

		if ( $settings['attr_price'] == 'true' && $settings['attr_view_button'] == 'true' && $settings['attr_book_button'] == 'true' ) {
      $attr_classes .= ' attr-price-fullwidth-true';
    }

		$rooms_loop = new \WP_Query( $args );

		?>

    <!-- rooms -->
    <section class="knsl-transition-<?php echo esc_attr( $settings['bg_position'] ); ?> knsl-p-0-100">
      <?php kinsley_deco_svg( 'left' ); ?>

      <div class="container">
        <div class="row align-items-center">
          <?php if ( $settings['title'] || $settings['more'] || $settings['description'] ) : ?>
          <div class="col-lg-12">
            <div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
              <?php if ( $settings['title'] ) : ?>
              <<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
                <span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
                    <?php echo wp_kses_post( $settings['title'] ); ?>
                </span>
              </<?php echo esc_attr( $settings['title_tag'] ); ?>>
              <?php endif; ?>
              <?php if ( $settings['description'] ) : ?>
              <div class="knsl-text knsl-mb-30">
                <p>
                  <span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
                      <?php echo wp_kses_post( $settings['description'] ); ?>
                  </span>
                </p>
              </div>
              <?php endif; ?>
              <?php if ( $settings['more'] ) : ?>
              <a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
                <span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
                    <?php echo wp_kses_post( $settings['more'] ); ?>
                </span>
              </a>
              <?php endif; ?>
            </div>
          </div>
          <?php endif; ?>

          <div class="col-lg-12<?php echo esc_attr( $attr_classes ); ?>">
            <?php if ( $rooms_loop->have_posts() ) : ?>
            <div class="swiper-container knsl-uni-slider">
              <div class="swiper-wrapper">
                <?php while ( $rooms_loop->have_posts() ) : $rooms_loop->the_post();
								$room_id = get_the_ID();
								set_query_var( 'layout', 'column-3' );
								?>
                <div class="swiper-slide">
                  <?php echo do_shortcode( '[mphb_room id="' . $room_id . '" title="' . $settings['attr_title'] . '" featured_image="' . $settings['attr_featured_image'] . '" gallery="' . $settings['attr_gallery'] . '" excerpt="' . $settings['attr_excerpt'] . '" details="' . $settings['attr_details'] . '" price="' . $settings['attr_price'] . '" view_button="' . $settings['attr_view_button'] . '" book_button="' . $settings['attr_book_button'] . '" class="knsl-scroll-animation"]' ); ?>
                </div>
                <?php endwhile; ?>
              </div>

              <!-- slider navigation -->
              <div class="knsl-uni-slider-nav-panel">
                <div class="knsl-uni-slider-pagination"></div>
                <div class="knsl-uni-nav">
                  <div class="knsl-uni-slider-prev"><i class="fas fa-arrow-left"></i></div>
                  <div class="knsl-uni-slider-next"><i class="fas fa-arrow-right"></i></div>
                </div>
              </div>
              <!-- slider navigation end -->

            </div>
            <?php endif; wp_reset_postdata(); ?>
          </div>
        </div>
      </div>
    </section>
    <!-- rooms end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Rooms_Carousel_Widget() );
