<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Rooms Grid Widget.
 *
 * @since 1.0
 */
class Kinsley_Rooms_Grid_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-rooms-grid';
	}

	public function get_title() {
		return esc_html__( 'Rooms (Grid)', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'heading_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

    $this->add_control(
			'heading',
			[
				'label'       => esc_html__( 'Heading', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'categories' => __( 'Categories', 'kinsley-plugin' ),
					'tags' => __( 'Tags', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_categories',
			[
				'label'       => esc_html__( 'Categories', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_categories(),
				'condition' => [
            'source' => 'categories'
        ],
			]
		);

		$this->add_control(
			'source_tags',
			[
				'label'       => esc_html__( 'Tags', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_tags(),
				'condition' => [
            'source' => 'tags'
        ],
			]
		);

		$this->add_control(
			'source_custom',
			[
				'label'       => esc_html__( 'Custom Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_rooms_custom(),
				'condition' => [
            'source' => 'custom'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 6,
				'default'     => 6,
			]
		);

    $this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'menu_order',
				'options' => [
					'none'           => __('No order', 'kinsley-plugin'),
					'ID'             => __('Post ID', 'kinsley-plugin'),
					'author'         => __('Post author', 'kinsley-plugin'),
					'title'          => __('Post title', 'kinsley-plugin'),
					'name'           => __('Post name (post slug)', 'kinsley-plugin'),
					'date'           => __('Post date', 'kinsley-plugin'),
					'modified'       => __('Last modified date', 'kinsley-plugin'),
					'parent'         => __('Parent ID', 'kinsley-plugin'),
					'rand'           => __('Random order', 'kinsley-plugin'),
					'comment_count'  => __('Number of comments', 'kinsley-plugin'),
					'relevance'      => __('Relevance', 'kinsley-plugin'),
					'menu_order'     => __('Page order', 'kinsley-plugin'),
					'meta_value'     => __('Meta value', 'kinsley-plugin'),
					'meta_value_num' => __('Numeric meta value', 'kinsley-plugin'),
					'post__in'       => __('Price', 'kinsley-plugin')
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'ASC',
				'options' => [
					'ASC'            => __('Ascending (1, 2, 3)', 'kinsley-plugin'),
					'DESC'           => __('Descending (3, 2, 1)', 'kinsley-plugin')
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'filters',
			[
				'label'       => esc_html__( 'Filters (by Category)', 'kinsley-plugin' ),
				'description' => esc_html__( '* 1) This option automatically activated masonry option for grid. 2) With selected pagination option "pages" filter works only for current page num.', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'masonry',
			[
				'label'       => esc_html__( 'Masonry Grid', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'kinsley-plugin' ),
				'label_off' => __( 'No', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'layout',
			[
				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'column-3',
				'options' => [
					'column-1'  => __( '1 Columns', 'kinsley-plugin' ),
					'column-2'  => __( '2 Columns', 'kinsley-plugin' ),
					'column-3' => __( '3 Columns', 'kinsley-plugin' ),
				],
			]
		);

    $this->add_control('attr_title', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Title', 'kinsley-plugin'),
        'description' => __('Whether to display title of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_featured_image', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Featured image', 'kinsley-plugin'),
        'description' => __('Whether to display featured image of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_gallery', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Gallery', 'kinsley-plugin'),
        'description' => __('Whether to display gallery of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_excerpt', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Excerpt', 'kinsley-plugin'),
        'description' => __('Whether to display excerpt (short description) of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Details', 'kinsley-plugin'),
        'description' => __('Whether to display details of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_capacity', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - capacity', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_children', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - children', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_amenity', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - amenities', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_size', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - size', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_category', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - categories', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_details_attributes', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - attributes', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_view', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - view', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_details_bed_type', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __(' - bed type', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_price', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Price', 'kinsley-plugin'),
        'description' => __('Whether to display price of the accommodation type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_view_button', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('View Button', 'kinsley-plugin'),
        'description' => __('Whether to display "View Details" button with the link to accommodation type.', 'kinsley-plugin'),
        'default'     => 'false',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_book_button', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Book Button', 'kinsley-plugin'),
        'description' => __('Whether to display "Book" button.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->end_controls_section();

		$this->start_controls_section(
			'pagination_tab',
			[
				'label' => esc_html__( 'Pagination', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'pagination',
			[
				'label'       => esc_html__( 'Pagination Type', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'pages',
				'options' => [
					'pages' => __( 'Pages', 'kinsley-plugin' ),
					'button' => __( 'Button', 'kinsley-plugin' ),
					'no' => __( 'No', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'more_text',
			[
				'label'       => esc_html__( 'More Text', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter text', 'kinsley-plugin' ),
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->add_control(
			'more_btn_txt',
			[
				'label'       => esc_html__( 'Button (title)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter button', 'kinsley-plugin' ),
				'default'     => esc_html__( 'All Posts', 'kinsley-plugin' ),
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->add_control(
			'more_btn_link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::URL,
				'show_external' => true,
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

    $this->start_controls_section(
			'filters_styling',
			[
				'label'     => esc_html__( 'Filters', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'filters_color',
			[
				'label'     => esc_html__( 'Filters Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-filter .knsl-work-category' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'filters_active_color',
			[
				'label'     => esc_html__( 'Filters Active Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-filter .knsl-work-category.knsl-current' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'filters_typography',
				'label'     => esc_html__( 'Filters Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-filter .knsl-work-category',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

    $this->add_control(
			'item_bg_color',
			[
				'label'     => esc_html__( 'Item BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_details_bgcolor',
			[
				'label'     => esc_html__( 'Details BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_details_color',
			[
				'label'     => esc_html__( 'Details Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_details_typography',
				'label'     => esc_html__( 'Details Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-loop-room-type-attributes',
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type h2 a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type h2',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .knsl-text-light' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .knsl-text-light',
			]
		);

    $this->add_control(
			'item_price_color',
			[
				'label'     => esc_html__( 'Price Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_typography',
				'label'     => esc_html__( 'Price Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-price',
			]
		);

    $this->add_control(
			'item_price_after_color',
			[
				'label'     => esc_html__( 'Price After Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-price-period' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_after_typography',
				'label'     => esc_html__( 'Price After Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-price-period',
			]
		);

    $this->add_control(
			'item_btn_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-book-button' => 'color: {{VALUE}};',
				],
			]
		);

    $this->add_control(
			'item_btn_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .mphb-room-type .mphb-book-button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_btn_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .mphb-room-type .mphb-book-button',
			]
		);

		$this->end_controls_section();

    $this->start_controls_section(
			'pagination_styling',
			[
				'label'     => esc_html__( 'Pagination', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'pagination_color',
			[
				'label'     => esc_html__( 'Pagination Links Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-pagination a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'pagination_typography',
				'label'     => esc_html__( 'Pagination Links Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-pagination',
			]
		);

		$this->add_control(
			'more_button_color',
			[
				'label'     => esc_html__( 'More Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-read-more .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'more_button_bgcolor',
			[
				'label'     => esc_html__( 'More Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-read-more .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'more_button_typography',
				'label'     => esc_html__( 'More Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-read-more .knsl-btn',
			]
		);

		$this->end_controls_section();
	}

  /**
	 * Render Categories List.
	 *
	 * @since 1.0
	 */
	protected function get_rooms_categories() {
		$categories = [];

		$args = array(
			'type'			=> 'mphb_room_type',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'mphb_room_type_category',
			'pad_counts'	=> false
		);

		$rooms_categories = get_categories( $args );

		foreach ( $rooms_categories as $category ) {
			$categories[$category->term_id] = $category->name;
		}

		return $categories;
	}

	protected function get_rooms_tags() {
		$tags = [];

		$args = array(
			'type'			=> 'mphb_room_type',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'mphb_room_type_tag',
			'pad_counts'	=> false
		);

		$rooms_tags = get_categories( $args );

		foreach ( $rooms_tags as $tag ) {
			$tags[$tag->term_id] = $tag->name;
		}

		return $tags;
	}

	protected function get_rooms_custom() {
		$items = [];

		$args = array(
			'post_type'			=> 'mphb_room_type',
			'post_status'		=> 'publish',
			'posts_per_page'	=> -1
		);

		$rooms_items = new \WP_Query( $args );

		while ( $rooms_items->have_posts() ) : $rooms_items->the_post();
			$items[get_the_ID()] = get_the_title();
		endwhile; wp_reset_postdata();

		return $items;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

    $this->add_inline_editing_attributes( 'more', 'none' );
		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );

    $paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;
		$page_id = get_the_ID();
		$ids = '';
		$cat_ids = '';

		if ( $settings['source'] == 'categories' ) {
			$ids = $settings['source_categories'];
      $cat_ids = $ids;
		} elseif ( $settings['source'] == 'tags' ) {
			$ids = $settings['source_tags'];
		} elseif ( $settings['source'] == 'custom' ) {
			$ids = $settings['source_custom'];
		} else {}

    $cat_args = array(
			'type'			=> 'mphb_room_type',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'mphb_room_type_category',
			'pad_counts'	=> false,
			'include'		=> $cat_ids
		);

		$rp_categories = get_categories( $cat_args );

		$args = array(
			'post_type'			=> 'mphb_room_type',
			'post_status'		=> 'publish',
			'orderby'			=> $settings['sort'],
			'order'				=> $settings['order'],
			'posts_per_page'	=> $settings['limit'],
      'paged' 			=> $paged
		);

		if ( $settings['source'] == 'categories' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'mphb_room_type_category',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'tags' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'mphb_room_type_tag',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'custom' ) {
			$args += array( 'post__in' => $ids );
		}

		$attr_classes = '';
		$item_classes = '';

		if ( $settings['masonry'] == 'yes' ) {
			if ( $settings['layout'] == 'column-1' ) {
				$attr_classes = 'knsl-masonry-grid knsl-1-col';
				$item_classes = 'knsl-masonry-grid-item knsl-masonry-grid-item-100';
	    } elseif ( $settings['layout'] == 'column-2' ) {
	      $attr_classes = 'knsl-masonry-grid knsl-2-col';
	      $item_classes = 'knsl-masonry-grid-item knsl-masonry-grid-item-50';
	    } else {
	      $attr_classes = 'knsl-masonry-grid knsl-3-col';
	      $item_classes = 'knsl-masonry-grid-item knsl-masonry-grid-item-33';
	    }
		} else {
			$attr_classes = 'row';

			if ( $settings['layout'] == 'column-1' ) {
				$item_classes = 'col-lg-12';
	    } elseif ( $settings['layout'] == 'column-2' ) {
	      $item_classes = 'col-lg-6';
	    } else {
	      $item_classes = 'col-lg-4';
	    }
		}

    if ( $settings['attr_details_capacity'] == 'false' ) {
      $attr_classes .= ' attr-details-capacity-false';
    }
    if ( $settings['attr_details_size'] == 'false' ) {
      $attr_classes .= ' attr-details-size-false';
    }
    if ( $settings['attr_details_amenity'] == 'false' ) {
      $attr_classes .= ' attr-details-amenity-false';
    }
    if ( $settings['attr_details_category'] == 'false' ) {
      $attr_classes .= ' attr-details-category-false';
    }
    if ( $settings['attr_details_attributes'] == 'false' ) {
      $attr_classes .= ' attr-details-attributes-false';
    }
		if ( $settings['attr_details_view'] == 'false' ) {
      $attr_classes .= ' attr-details-view-false';
    }
		if ( $settings['attr_details_bed_type'] == 'false' ) {
      $attr_classes .= ' attr-details-bed-type-false';
    }
		if ( $settings['attr_details_children'] == 'false' ) {
      $attr_classes .= ' attr-details-children-false';
    }

    if ( $settings['attr_price'] == 'true' && $settings['attr_view_button'] == 'true' && $settings['attr_book_button'] == 'true' ) {
      $attr_classes .= ' attr-price-fullwidth-true';
    }

		$rooms_loop = new \WP_Query( $args );

		?>

    <!-- rooms -->
    <section class="knsl-p-0-100">
      <?php kinsley_deco_svg( 'left' ); ?>

      <div class="container">
        <?php if ( $settings['title'] || $settings['more'] || $settings['description'] ) : ?>
        <div class="row">
          <div class="col-lg-12">
            <div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
              <?php if ( $settings['title'] ) : ?>
              <<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
                <span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
                    <?php echo wp_kses_post( $settings['title'] ); ?>
                </span>
              </<?php echo esc_attr( $settings['title_tag'] ); ?>>
              <?php endif; ?>
              <?php if ( $settings['description'] ) : ?>
              <div class="knsl-text knsl-mb-30">
                <p>
                  <span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
                      <?php echo wp_kses_post( $settings['description'] ); ?>
                  </span>
                </p>
              </div>
              <?php endif; ?>
              <?php if ( $settings['more'] ) : ?>
              <a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
                <span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
                    <?php echo wp_kses_post( $settings['more'] ); ?>
                </span>
              </a>
              <?php endif; ?>
            </div>
          </div>
        </div>
        <?php endif; ?>

        <?php if ($rp_categories && $settings['filters'] == 'yes' && $settings['masonry'] == 'yes' ) : ?>
        <div class="knsl-filter knsl-mb-60">
          <a href="#" data-filter="*" class="knsl-work-category knsl-current"><?php echo esc_html__( 'All Rooms', 'kinsley-plugin' ); ?></a>
          <?php foreach ( $rp_categories as $category ) : ?>
          <a href="#" data-filter=".<?php echo esc_attr( $category->slug ); ?>" class="knsl-work-category"><?php echo esc_html( $category->name ); ?></a>
          <?php endforeach; ?>
        </div>
        <?php endif; ?>

        <?php if ( $rooms_loop->have_posts() ) : ?>
        <div class="<?php echo esc_attr( $attr_classes ); ?>">
					<?php if ( $settings['masonry'] == 'yes' ) : ?>
					<div class="knsl-grid-sizer"></div>
					<?php endif; ?>

          <?php
          $i=0; while ( $rooms_loop->have_posts() ) : $rooms_loop->the_post(); $i++;
          $room_id = get_the_ID();
					$categories_slugs = '';
					if ( $settings['masonry'] == 'yes' ) {
	          $current_categories = get_the_terms( $room_id, 'mphb_room_type_category' );
	          if ( $current_categories && ! is_wp_error( $current_categories ) ) {
	          	foreach ( $current_categories as $key => $value ) {
	          		$categories_slugs .= ' ' . $value->slug;
	          	}
	          }
					}

          set_query_var( 'layout', $settings['layout'] );
          set_query_var( 'index', $i );

          $scroll_animation = '';
          if ( $i > 3 && $settings['layout'] == 'column-3' ) {
            $scroll_animation = 'knsl-scroll-animation';
          }
          if ( $i > 2 && $settings['layout'] == 'column-2' ) {
            $scroll_animation = 'knsl-scroll-animation';
          }
          if ( $i > 1 && $settings['layout'] == 'column-1' ) {
            $scroll_animation = 'knsl-scroll-animation';
          }
          ?>
          <div class="<?php echo esc_attr( $item_classes ); ?> <?php echo esc_attr( $categories_slugs ); ?>">
            <?php echo do_shortcode( '[mphb_room id="' . $room_id . '" title="' . $settings['attr_title'] . '" featured_image="' . $settings['attr_featured_image'] . '" gallery="' . $settings['attr_gallery'] . '" excerpt="' . $settings['attr_excerpt'] . '" details="' . $settings['attr_details'] . '" price="' . $settings['attr_price'] . '" view_button="' . $settings['attr_view_button'] . '" book_button="' . $settings['attr_book_button'] . '" class="' . $scroll_animation . '"]' ); ?>
          </div>
          <?php endwhile; ?>
        </div>
        <?php if ( $settings['pagination'] == 'pages' ) : ?>
        <!-- pagination -->
        <div class="knsl-pagination">
          <?php
            $big = 999999999; // need an unlikely integer

            echo paginate_links( array(
              'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
              'format' => '?paged=%#%',
              'current' => max( 1, get_query_var('paged') ),
              'total' => $rooms_loop->max_num_pages,
              'prev_text' => esc_html__( 'Prev', 'kinsley-plugin' ),
              'next_text' => esc_html__( 'Next', 'kinsley-plugin' ),
            ) );
          ?>
        </div>
        <!-- pagination end -->
        <?php endif; ?>

        <?php if ( $settings['pagination'] == 'button' ) : ?>
        <!-- read more -->
				<div class="knsl-read-more">
					<?php if ( $settings['more_text'] ) : ?>
					<div class="knsl-text">
						<span <?php echo $this->get_render_attribute_string( 'more_text' ); ?>>
							<?php echo wp_kses_post( $settings['more_text'] ); ?>
						</span>
					</div>
					<?php endif; ?>
					<a<?php if ( $settings['more_btn_link'] ) : ?><?php if ( $settings['more_btn_link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['more_btn_link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['more_btn_link']['url'] ); ?>"<?php endif; ?> class="knsl-btn">
						<span <?php echo $this->get_render_attribute_string( 'more_btn_txt' ); ?>>
							<?php echo wp_kses_post( $settings['more_btn_txt'] ); ?>
						</span>
					</a>
				</div>
				<!-- read more end -->
        <?php endif; ?>
        <?php else :
          get_template_part( 'template-parts/content', 'none' );
        endif; wp_reset_postdata(); ?>
      </div>
    </section>
    <!-- rooms end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Rooms_Grid_Widget() );
