<?php

namespace Elementor;

use \Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Search Form Widget.
 *
 * @since 1.0
 */
class Kinsley_MPHB_Search_Form_Widget extends Kinsley_MPHB_AbstractWidget
{
    public function get_name() {
  		return 'kinsley-mphb-search-form';
  	}

  	public function get_title() {
  		return esc_html__( 'Room / Search Availability Form', 'kinsley-plugin' );
  	}

  	public function get_icon() {
  		return 'eicon-parallax';
  	}

  	public function get_categories() {
  		return [ 'kinsley-category' ];
  	}

    /**
  	 * Register widget controls.
  	 *
  	 * @since 1.0
  	 */
    protected function register_controls()
    {
        $minAdults   = MPHB()->settings()->main()->getMinAdults();
        $maxAdults   = MPHB()->settings()->main()->getSearchMaxAdults();
        $minChildren = MPHB()->settings()->main()->getMinChildren();
        $maxChildren = MPHB()->settings()->main()->getSearchMaxChildren();
        $dateFormat  = MPHB()->settings()->dateTime()->getDateFormat();

        $this->start_controls_section('section_parameters', array(
            'label'       => __('Parameters', 'kinsley-plugin')
        ));

        $this->add_control(
    			'layout',
    			[
    				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
    				'type'        => Controls_Manager::SELECT,
    				'default' => 'vertical',
    				'options' => [
    					'vertical'  => __( 'Vertical', 'kinsley-plugin' ),
    					'horizontal' => __( 'Horizontal', 'kinsley-plugin' ),
    				],
    			]
    		);

        $this->add_control('adults', array(
            'type'        => Controls_Manager::NUMBER,
            'label'       => __('Adults', 'kinsley-plugin'),
            'description' => __('The number of adults presetted in the search form.', 'kinsley-plugin'),
            'default'     => $minAdults,
            'min'         => $minAdults,
            'max'         => $maxAdults
        ));

        $this->add_control('children', array(
            'type'        => Controls_Manager::NUMBER,
            'label'       => __('Children', 'kinsley-plugin'),
            'description' => __('The number of children presetted in the search form.', 'kinsley-plugin'),
            'default'     => $minChildren,
            'min'         => $minChildren,
            'max'         => $maxChildren
        ));

        $this->add_control('check_in_date', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Check-in date', 'kinsley-plugin'),
            'description' => __('Check-in date presetted in the search form.', 'kinsley-plugin'),
            'placeholder' => $dateFormat,
            'default'     => ''
        ));

        $this->add_control('check_out_date', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Check-out date', 'kinsley-plugin'),
            'description' => __('Check-out date presetted in the search form.', 'kinsley-plugin'),
            'placeholder' => $dateFormat,
            'default'     => ''
        ));

        $this->add_control('attributes', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Attributes', 'kinsley-plugin'),
            'description' => __('Custom attributes for advanced search.', 'kinsley-plugin'),
            'placeholder' => __('Slugs of attributes', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->add_control(
    			'sticky',
    			[
    				'label'       => esc_html__( 'Sticky', 'kinsley-plugin' ),
    				'type' => Controls_Manager::SWITCHER,
    				'label_on' => __( 'Yes', 'kinsley-plugin' ),
    				'label_off' => __( 'No', 'kinsley-plugin' ),
    				'return_value' => 'yes',
    				'default' => 'no',
    			]
    		);

        $this->add_control('sticky_offset_top', array(
            'type'        => Controls_Manager::NUMBER,
            'label'       => __('Sticky Offset Top', 'kinsley-plugin'),
            'default'     => 100,
            'condition' => [
                'sticky' => 'yes',
            ]
        ));

        $this->add_control('class', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Class', 'kinsley-plugin'),
            'description' => __('Custom CSS class for shortcode wrapper.', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->end_controls_section();
    }

    /**
  	 * Render widget output on the frontend.
  	 *
  	 * @since 1.0
  	 */
    protected function render()
    {

        $atts = $this->get_settings();

        $className = ! empty( $atts[ 'class' ] ) ? $atts[ 'class' ] : '';

        $atts[ 'class' ]  = ! empty( $atts[ 'widget_styles' ] ) ? $atts[ 'widget_styles' ] : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'hide_labels' ] ) ? $atts[ 'hide_labels' ] === 'yes' ? 'mphbs-hide-labels ' : '' : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'no_paddings' ] ) ? $atts[ 'no_paddings' ] === 'yes' ? 'mphbs-no-paddings ' : '' : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'hide_tips' ] ) ? $atts[ 'hide_tips' ] === 'yes' ? 'mphbs-hide-rf-tip ' : '' : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'multiple_lines' ] ) ? $atts[ 'multiple_lines' ] === 'yes' ? 'mphbs-wrap ' : '' : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'stretch_btn' ] ) ? $atts[ 'stretch_btn' ] === 'yes' ? 'mphbs-fluid-button ' : '' : '';
        $atts[ 'class' ] .= ! empty( $atts[ 'fields_width' ] ) ? $atts[ 'fields_width' ] : '';
        $atts[ 'class' ] .= $className;

        if ( $atts['layout'] == 'vertical' ) {
          $atts[ 'class' ] .= ' knsl-book-form knsl-book-form-v';
        }
        if ( $atts['layout'] == 'horizontal' ) {
          $atts[ 'class' ] .= ' knsl-book-form knsl-book-form-2';
        }
        ?>
        <?php if ( $atts['sticky'] == 'yes' ) : ?>
        <div class="knsl-sticky knsl-stycky-right" data-margin-top="<?php echo esc_attr( $atts['sticky_offset_top'] ); ?>">
        <?php endif; ?>
        <?php
        do_action('mphbe_before_search_form_widget_render', $atts);

        $shortcode = MPHB()->getShortcodes()->getSearch();
        echo $shortcode->render($atts, null, $shortcode->getName()); // phpcs:ignore

        do_action('mphbe_after_search_form_widget_render', $atts);
        ?>
        <?php if ( $atts['sticky'] == 'yes' ) : ?>
        </div>
        <?php endif; ?>
        <?php
    }
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_MPHB_Search_Form_Widget() );
