<?php

namespace Elementor;

use \Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Search Form Widget.
 *
 * @since 1.0
 */
class Kinsley_MPHB_SearchResultsWidget extends Kinsley_MPHB_AbstractWidget
{
    public function get_name() {
  		return 'kinsley-mphb-search-results';
  	}

  	public function get_title() {
  		return esc_html__( 'Room / Search Results', 'kinsley-plugin' );
  	}

  	public function get_icon() {
  		return 'eicon-parallax';
  	}

  	public function get_categories() {
  		return [ 'kinsley-category' ];
  	}

    /**
  	 * Register widget controls.
  	 *
  	 * @since 1.0
  	 */
    protected function register_controls()
    {
        $this->start_controls_section('section_parameters', array(
            'label'       => __('Parameters', 'kinsley-plugin')
        ));

        $this->add_control('title', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Title', 'kinsley-plugin'),
            'description' => __('Whether to display title of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('featured_image', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Featured image', 'kinsley-plugin'),
            'description' => __('Whether to display featured image of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('gallery', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Gallery', 'kinsley-plugin'),
            'description' => __('Whether to display gallery of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('excerpt', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Excerpt', 'kinsley-plugin'),
            'description' => __('Whether to display excerpt (short description) of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('details', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Details', 'kinsley-plugin'),
            'description' => __('Whether to display details of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('attr_details_capacity', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - capacity', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

    		$this->add_control('attr_details_children', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - children', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('attr_details_amenity', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - amenities', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('attr_details_size', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - size', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('attr_details_category', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - categories', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('attr_details_attributes', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - attributes', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

    		$this->add_control('attr_details_view', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - view', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

    		$this->add_control('attr_details_bed_type', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __(' - bed type', 'kinsley-plugin'),
            'default'     => 'false',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('price', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Price', 'kinsley-plugin'),
            'description' => __('Whether to display price of the accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('view_button', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('View button', 'kinsley-plugin'),
            'description' => __('Whether to display "View Details" button with the link to accommodation type.', 'kinsley-plugin'),
            'default'     => 'true',
            'options'     => array(
                'true'          => __('Yes', 'kinsley-plugin'),
                'false'         => __('No', 'kinsley-plugin')
            )
        ));

        $this->add_control('class', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Class', 'kinsley-plugin'),
            'description' => __('Custom CSS class for shortcode wrapper.', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->end_controls_section();

        $this->start_controls_section('section_order', array(
            'label'       => __('Order', 'kinsley-plugin')
        ));

        $this->add_control('orderby', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Order By', 'kinsley-plugin'),
            'default'     => 'menu_order',
            'options'     => array(
                'none'           => __('No order', 'kinsley-plugin'),
                'ID'             => __('Post ID', 'kinsley-plugin'),
                'author'         => __('Post author', 'kinsley-plugin'),
                'title'          => __('Post title', 'kinsley-plugin'),
                'name'           => __('Post name (post slug)', 'kinsley-plugin'),
                'date'           => __('Post date', 'kinsley-plugin'),
                'modified'       => __('Last modified date', 'kinsley-plugin'),
                'parent'         => __('Parent ID', 'kinsley-plugin'),
                'rand'           => __('Random order', 'kinsley-plugin'),
                'comment_count'  => __('Number of comments', 'kinsley-plugin'),
                'relevance'      => __('Relevance', 'kinsley-plugin'),
                'menu_order'     => __('Page order', 'kinsley-plugin'),
                'meta_value'     => __('Meta value', 'kinsley-plugin'),
                'meta_value_num' => __('Numeric meta value', 'kinsley-plugin'),
                'post__in'       => __('Price', 'kinsley-plugin')
            )
        ));

        $this->add_control('order', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Order', 'kinsley-plugin'),
            'default'     => 'DESC',
            'options'     => array(
                'ASC'            => __('Ascending (1, 2, 3)', 'kinsley-plugin'),
                'DESC'           => __('Descending (3, 2, 1)', 'kinsley-plugin')
            )
        ));

        $this->add_control('meta_key', array(
            'type'        => Controls_Manager::TEXT,
            'label'       => __('Meta Name', 'kinsley-plugin'),
            'description' => __('Custom field name. Required if "orderby" is one of the "meta_value", "meta_value_num" or "meta_value_*".', 'kinsley-plugin'),
            'default'     => ''
        ));

        $this->add_control('meta_type', array(
            'type'        => Controls_Manager::SELECT,
            'label'       => __('Meta Type', 'kinsley-plugin'),
            'description' => __('Specified type of the custom field. Can be used in conjunction with "orderby" = "meta_value".', 'kinsley-plugin'),
            'default'     => '',
            'options'     => array(
                ''               => __('Any', 'kinsley-plugin'),
                'NUMERIC'        => __('Numeric', 'kinsley-plugin'),
                'BINARY'         => __('Binary', 'kinsley-plugin'),
                'CHAR'           => __('String', 'kinsley-plugin'),
                'DATE'           => __('Date', 'kinsley-plugin'),
                'TIME'           => __('Time', 'kinsley-plugin'),
                'DATETIME'       => __('Date and time', 'kinsley-plugin'),
                'DECIMAL'        => __('Decimal number', 'kinsley-plugin'),
                'SIGNED'         => __('Signed number', 'kinsley-plugin'),
                'UNSIGNED'       => __('Unsigned number', 'kinsley-plugin')
            )
        ));

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     */
    protected function render()
    {

        $atts = $this->get_settings();

        if ( $atts['attr_details_capacity'] == 'false' ) {
          $atts['class'] .= ' attr-details-capacity-false';
        }
        if ( $atts['attr_details_size'] == 'false' ) {
          $atts['class'] .= ' attr-details-size-false';
        }
        if ( $atts['attr_details_amenity'] == 'false' ) {
          $atts['class'] .= ' attr-details-amenity-false';
        }
        if ( $atts['attr_details_category'] == 'false' ) {
          $atts['class'] .= ' attr-details-category-false';
        }
        if ( $atts['attr_details_attributes'] == 'false' ) {
          $atts['class'] .= ' attr-details-attributes-false';
        }
    		if ( $atts['attr_details_view'] == 'false' ) {
          $atts['class'] .= ' attr-details-view-false';
        }
    		if ( $atts['attr_details_bed_type'] == 'false' ) {
          $atts['class'] .= ' attr-details-bed-type-false';
        }
    		if ( $atts['attr_details_children'] == 'false' ) {
          $atts['class'] .= ' attr-details-children-false';
        }

        do_action('mphbe_before_search_results_widget_render', $atts);

        $shortcode = MPHB()->getShortcodes()->getSearchResults();
        echo $shortcode->render($atts, null, $shortcode->getName()); // phpcs:ignore

        do_action('mphbe_after_search_results_widget_render', $atts);

    }
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_MPHB_SearchResultsWidget() );
