<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Numbers Widget.
 *
 * @since 1.0
 */
class Kinsley_Numbers_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-numbers';
	}

	public function get_title() {
		return esc_html__( 'Numbers', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'value', [
				'label'       => esc_html__( 'Number Value', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter number value', 'kinsley-plugin' ),
				'default'	=> 99,
			]
		);

		$repeater->add_control(
			'label', [
				'label'       => esc_html__( 'Label', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter label', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Label', 'kinsley-plugin' ),
			]
		);

		$repeater->add_control(
			'plus',
			[
				'label'       => esc_html__( 'Plus', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'kinsley-plugin' ),
				'label_off' => __( 'No', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'items',
			[
				'label' => esc_html__( 'Numbers Items', 'kinsley-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'prevent_empty' => false,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ label }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'bg_position',
			[
				'label'       => esc_html__( 'BG Transition Position', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'top'  => __( 'Top', 'kinsley-plugin' ),
					'bottom' => __( 'Bottom', 'kinsley-plugin' ),
					'middle' => __( 'Middle', 'kinsley-plugin' ),
					'none' => __( 'None', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_bgcolor',
			[
				'label'     => esc_html__( 'Background Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-icon-box' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_value_color',
			[
				'label'     => esc_html__( 'Number Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-icon-box .knsl-counter-number' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_value_typography',
				'label'     => esc_html__( 'Number Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-icon-box .knsl-counter-number',
			]
		);

		$this->add_control(
			'item_label_color',
			[
				'label'     => esc_html__( 'Label Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-icon-box h5' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_label_typography',
				'label'     => esc_html__( 'Label Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-icon-box h5',
			]
		);

		$this->end_controls_section();
	}


	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		?>

		<!-- counters -->
	    <section class="knsl-transition-<?php echo esc_attr( $settings['bg_position'] ); ?> knsl-p-0-100">
	      <?php kinsley_deco_svg( 'right' ); ?>

	      <div class="container">
	      	<?php if ( $settings['items'] ) : ?>
	        <!-- features card -->
	        <div class="knsl-features-card knsl-counters-card knsl-scroll-animation">

	          <div class="row">
	            <?php foreach ( $settings['items'] as $index => $item ) :
				  $item_value = $this->get_repeater_setting_key( 'value', 'items', $index );
				  $this->add_inline_editing_attributes( $item_value, 'none' );

				  $item_label = $this->get_repeater_setting_key( 'label', 'items', $index );
				  $this->add_inline_editing_attributes( $item_label, 'basic' );
				?>
	            <div class="col-6 col-lg-3">

	              <!-- icon box -->
	              <div class="knsl-icon-box">
	                <span class="knsl-counter-number knsl-mb-10" data-count="<?php echo esc_attr( $item['value'] ); ?>"></span>
									<?php if ( $item['plus'] == 'yes' ) : ?>
									<span class="knsl-counter-number"><?php echo esc_html__( '+', 'kinsley-plugin' ); ?></span>
									<?php endif; ?>
	                <h5><?php echo wp_kses_post( $item['label'] ); ?></h5>
	              </div>
	              <!-- icon box end -->

	            </div>
	            <?php endforeach; ?>
	          </div>

	        </div>
	        <!-- features card end -->
	        <?php endif; ?>
	      </div>
	    </section>
	    <!-- counters end -->

		<?php
	}

	/**
	 * Render widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template() {
		?>

		<!-- counters -->
	    <section class="knsl-transition-{{{ settings.bg_position }}} knsl-p-0-100">
	      <div class="container">
	      	<# if ( settings.items ) { #>
	        <!-- features card -->
	        <div class="knsl-features-card knsl-counters-card knsl-scroll-animation">

	          <div class="row">
	            <# _.each( settings.items, function( item, index ) {

				    var item_value = view.getRepeaterSettingKey( 'value', 'items', index );
				    view.addInlineEditingAttributes( item_value, 'none' );

				    var item_label = view.getRepeaterSettingKey( 'label', 'items', index );
				    view.addInlineEditingAttributes( item_label, 'basic' );

				#>
	            <div class="col-6 col-lg-3">

	              <!-- icon box -->
	              <div class="knsl-icon-box">
	                <span class="knsl-counter-number knsl-mb-10" data-count="{{{ item.value }}}"></span>
									<# if ( item.plus == 'yes' ) { #>
									<span class="knsl-counter-number">+</span>
									<# } #>
	                <h5>{{{ item.label }}}</h5>
	              </div>
	              <!-- icon box end -->

	            </div>
	            <# }); #>
	          </div>

	        </div>
	        <!-- features card end -->
	        <# } #>
	      </div>
	    </section>
	    <!-- counters end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Numbers_Widget() );
