<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Restaurant Menu Carousel Widget.
 *
 * @since 1.0
 */
class Kinsley_Restaurant_Menu_Carousel_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-restaurant-menu-carousel';
	}

	public function get_title() {
		return esc_html__( 'Restaurant Menu (Carousel)', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'categories' => __( 'Categories', 'kinsley-plugin' ),
					'tags' => __( 'Tags', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_categories',
			[
				'label'       => esc_html__( 'Categories', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_restaurant_menu_categories(),
				'condition' => [
            'source' => 'categories'
        ],
			]
		);

		$this->add_control(
			'source_tags',
			[
				'label'       => esc_html__( 'Tags', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_restaurant_menu_tags(),
				'condition' => [
            'source' => 'tags'
        ],
			]
		);

		$this->add_control(
			'source_custom',
			[
				'label'       => esc_html__( 'Custom Menu Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_restaurant_menu_items_custom(),
				'condition' => [
            'source' => 'custom'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 6,
				'default'     => 6,
			]
		);

		$this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => [
					'date'  => __( 'Date', 'kinsley-plugin' ),
					'title' => __( 'Title', 'kinsley-plugin' ),
					'rand' => __( 'Random', 'kinsley-plugin' ),
					'menu_order' => __( 'Order', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'desc',
				'options' => [
					'asc'  => __( 'ASC', 'kinsley-plugin' ),
					'desc' => __( 'DESC', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'bg_position',
			[
				'label'       => esc_html__( 'BG Transition Position', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'top'  => __( 'Top', 'kinsley-plugin' ),
					'bottom' => __( 'Bottom', 'kinsley-plugin' ),
					'middle' => __( 'Middle', 'kinsley-plugin' ),
					'none' => __( 'None', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control('attr_featured_image', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Featured Image', 'kinsley-plugin'),
        'description' => __('Whether to display title of the menu item type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_badge', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Badge', 'kinsley-plugin'),
        'description' => __('Whether to display badge of the menu item type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->add_control('attr_title', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Title', 'kinsley-plugin'),
        'description' => __('Whether to display title of the menu item type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_excerpt', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Excerpt', 'kinsley-plugin'),
        'description' => __('Whether to display excerpt (short description) of the menu item type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_price', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Price', 'kinsley-plugin'),
        'description' => __('Whether to display price of the menu item type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_bg_color',
			[
				'label'     => esc_html__( 'Item BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-menu-card' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-menu-card h3' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-menu-card h3',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-menu-card .knsl-text-light' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-menu-card .knsl-text-light',
			]
		);

		$this->add_control(
			'item_price_color',
			[
				'label'     => esc_html__( 'Price Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-menu-card .knsl-description-frame .knsl-card-bottom .knsl-price' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_typography',
				'label'     => esc_html__( 'Price Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-menu-card .knsl-description-frame .knsl-card-bottom .knsl-price',
			]
		);

		$this->add_control(
			'item_price_after_color',
			[
				'label'     => esc_html__( 'Price After Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-menu-card .knsl-description-frame .knsl-card-bottom .knsl-price span' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_price_after_typography',
				'label'     => esc_html__( 'Price After Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-menu-card .knsl-description-frame .knsl-card-bottom .knsl-price span',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Categories List.
	 *
	 * @since 1.0
	 */
	protected function get_restaurant_menu_categories() {
		$categories = [];

		$args = array(
			'type'			=> 'restaurant_menu',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'restaurant_menu_categories',
			'pad_counts'	=> false
		);

		$menu_categories = get_categories( $args );

		foreach ( $menu_categories as $category ) {
			$categories[$category->term_id] = $category->name;
		}

		return $categories;
	}

	protected function get_restaurant_menu_tags() {
		$tags = [];

		$args = array(
			'type'			=> 'restaurant_menu',
			'child_of'		=> 0,
			'parent'		=> '',
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 1,
			'taxonomy'		=> 'post_tag',
			'pad_counts'	=> false
		);

		$menu_tags = get_categories( $args );

		foreach ( $menu_tags as $tag ) {
			$tags[$tag->term_id] = $tag->name;
		}

		return $tags;
	}

	protected function get_restaurant_menu_items_custom() {
		$items = [];

		$args = array(
			'post_type'			=> 'restaurant_menu',
			'post_status'		=> 'publish',
			'posts_per_page'	=> -1
		);

		$menu_items = new \WP_Query( $args );

		while ( $menu_items->have_posts() ) : $menu_items->the_post();
			$items[get_the_ID()] = get_the_title();
		endwhile; wp_reset_postdata();

		return $items;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );
		$this->add_inline_editing_attributes( 'more', 'basic' );

		$paged = 1;
		$page_id = get_the_ID();

		if ( $settings['source'] == 'categories' ) {
			$ids = $settings['source_categories'];
		} elseif ( $settings['source'] == 'tags' ) {
			$ids = $settings['source_tags'];
		} elseif ( $settings['source'] == 'custom' ) {
			$ids = $settings['source_custom'];
		} else {
			$ids = '';
		}

		$args = array(
			'post_type'			=> 'restaurant_menu',
			'post_status'		=> 'publish',
			'orderby'			=> $settings['sort'],
			'order'				=> $settings['order'],
			'posts_per_page'	=> $settings['limit'],
			'paged' 			=> $paged
		);

		if ( $settings['source'] == 'categories' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'restaurant_menu_categories',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'tags' ) {
			$tax_array = array(
				array(
					'taxonomy' => 'post_tag',
					'field'    => 'id',
					'terms'    => $ids
				)
			);

			$args += array('tax_query' => $tax_array);
		}
		if ( $settings['source'] == 'custom' ) {
			$args += array( 'post__in' => $ids );
		}

		$attr_classes = '';

		if ( $settings['attr_featured_image'] == 'false' ) {
      $attr_classes .= ' attr-featured-false';
    }
		if ( $settings['attr_title'] == 'false' ) {
      $attr_classes .= ' attr-title-false';
    }
		if ( $settings['attr_excerpt'] == 'false' ) {
      $attr_classes .= ' attr-desc-false';
    }
		if ( $settings['attr_price'] == 'false' ) {
      $attr_classes .= ' attr-price-false';
    }
		if ( $settings['attr_badge'] == 'false' ) {
      $attr_classes .= ' attr-badge-false';
    }

		$q = new \WP_Query( $args );

		?>

		<!-- menu -->
    <section class="knsl-transition-<?php echo esc_attr( $settings['bg_position'] ); ?> knsl-p-0-100">
			<?php kinsley_deco_svg( 'both' ); ?>

      <div class="container">
        <div class="row">
					<?php if ( $settings['title'] || $settings['more'] || $settings['description'] ) : ?>
					<div class="col-lg-12">
						<div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
							<?php if ( $settings['title'] ) : ?>
							<<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
								<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
										<?php echo wp_kses_post( $settings['title'] ); ?>
								</span>
							</<?php echo esc_attr( $settings['title_tag'] ); ?>>
							<?php endif; ?>
							<?php if ( $settings['description'] ) : ?>
							<p class="knsl-text knsl-mb-30">
								<span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
										<?php echo wp_kses_post( $settings['description'] ); ?>
								</span>
							</p>
							<?php endif; ?>
							<?php if ( $settings['more'] ) : ?>
							<a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
								<span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
										<?php echo wp_kses_post( $settings['more'] ); ?>
								</span>
							</a>
							<?php endif; ?>
						</div>
					</div>
					<?php endif; ?>

          <div class="col-lg-12 <?php echo esc_attr( $attr_classes ); ?>">

            <div class="swiper-container knsl-uni-slider">
							<?php if ( $q->have_posts() ) : ?>
							<div class="swiper-wrapper">
								<?php while ( $q->have_posts() ) : $q->the_post();
								set_query_var( 'layout', 'carousel' );
								?>
                <div class="swiper-slide">
									<?php get_template_part( 'template-parts/content', 'restaurant-menu' ); ?>
                </div>
								<?php endwhile; ?>
              </div>
							<?php endif; wp_reset_postdata(); ?>

              <!-- slider navigation -->
              <div class="knsl-uni-slider-nav-panel">
                <div class="knsl-uni-slider-pagination"></div>
                <div class="knsl-uni-nav">
                  <div class="knsl-uni-slider-prev"><i class="fas fa-arrow-left"></i></div>
                  <div class="knsl-uni-slider-next"><i class="fas fa-arrow-right"></i></div>
                </div>
              </div>
              <!-- slider navigation end -->

            </div>
          </div>
        </div>
      </div>
    </section>
    <!-- menu end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Restaurant_Menu_Carousel_Widget() );
