<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Services Widget.
 *
 * @since 1.0
 */
class Kinsley_Services_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-services';
	}

	public function get_title() {
		return esc_html__( 'Services', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'heading_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => esc_html__( 'Heading', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'more',
			[
				'label'       => esc_html__( 'Button (label)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Button', 'kinsley-plugin' ),
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type' => Controls_Manager::URL,
				'show_external' => true,
				'condition'   => [
					'heading' => 'yes'
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'source',
			[
				'label'       => esc_html__( 'Source', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'all',
				'options' => [
					'all'  => __( 'All', 'kinsley-plugin' ),
					'custom' => __( 'Custom', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'source_custom',
			[
				'label'       => esc_html__( 'Custom Menu Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => $this->get_services_items_custom(),
				'condition' => [
            'source' => 'custom'
        ],
			]
		);

		$this->add_control(
			'limit',
			[
				'label'       => esc_html__( 'Number of Items', 'kinsley-plugin' ),
				'type'        => Controls_Manager::NUMBER,
				'placeholder' => 6,
				'default'     => 6,
			]
		);

		$this->add_control(
			'sort',
			[
				'label'       => esc_html__( 'Sorting By', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'menu_order',
				'options' => [
					'date'  => __( 'Date', 'kinsley-plugin' ),
					'title' => __( 'Title', 'kinsley-plugin' ),
					'rand' => __( 'Random', 'kinsley-plugin' ),
					'menu_order' => __( 'Order', 'kinsley-plugin' ),
					'price'	=> __( 'Price', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => esc_html__( 'Order', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'asc',
				'options' => [
					'asc'  => __( 'ASC', 'kinsley-plugin' ),
					'desc' => __( 'DESC', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pagination_tab',
			[
				'label' => esc_html__( 'Pagination', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'pagination',
			[
				'label'       => esc_html__( 'Pagination Type', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'pages',
				'options' => [
					'pages' => __( 'Pages', 'kinsley-plugin' ),
					'button' => __( 'Button', 'kinsley-plugin' ),
					'no' => __( 'No', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'more_text',
			[
				'label'       => esc_html__( 'More Text', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter text', 'kinsley-plugin' ),
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->add_control(
			'more_btn_txt',
			[
				'label'       => esc_html__( 'Button (title)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter button', 'kinsley-plugin' ),
				'default'     => esc_html__( 'All Posts', 'kinsley-plugin' ),
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->add_control(
			'more_btn_link',
			[
				'label'       => esc_html__( 'Button (link)', 'kinsley-plugin' ),
				'type'        => Controls_Manager::URL,
				'show_external' => true,
				'condition' => [
            'pagination' => 'button'
        ],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout',
			[
				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'column-3',
				'options' => [
					'column-1'  => __( '1 Columns', 'kinsley-plugin' ),
					'column-2'  => __( '2 Columns', 'kinsley-plugin' ),
					'column-3' => __( '3 Columns', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control('attr_title', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Title', 'kinsley-plugin'),
        'description' => __('Whether to display title of the service type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_excerpt', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Excerpt', 'kinsley-plugin'),
        'description' => __('Whether to display excerpt (short description) of the service type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_price', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Price', 'kinsley-plugin'),
        'description' => __('Whether to display price of the service type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

    $this->add_control('attr_view_button', array(
        'type'        => Controls_Manager::SELECT,
        'label'       => __('Read More Button', 'kinsley-plugin'),
        'description' => __('Whether to display "Read more" button with the link to service type.', 'kinsley-plugin'),
        'default'     => 'true',
        'options'     => array(
            'true'          => __('Yes', 'kinsley-plugin'),
            'false'         => __('No', 'kinsley-plugin')
        )
    ));

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->add_control(
			'button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-ath-card .knsl-card-description h3' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-ath-card .knsl-card-description h3',
			]
		);

		$this->add_control(
			'item_desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-ath-card .knsl-card-description .knsl-text--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-ath-card .knsl-card-description .knsl-text--h',
			]
		);

		$this->add_control(
			'item_button_color',
			[
				'label'     => esc_html__( 'Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-ath-card .knsl-card-description .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_button_bgcolor',
			[
				'label'     => esc_html__( 'Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-ath-card .knsl-card-description .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_button_typography',
				'label'     => esc_html__( 'Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-ath-card .knsl-card-description .knsl-btn',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pagination_styling',
			[
				'label'     => esc_html__( 'Pagination', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'pagination_color',
			[
				'label'     => esc_html__( 'Pagination Links Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-pagination a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'pagination_typography',
				'label'     => esc_html__( 'Pagination Links Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-pagination',
			]
		);

		$this->add_control(
			'more_button_color',
			[
				'label'     => esc_html__( 'More Button Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-read-more .knsl-btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'more_button_bgcolor',
			[
				'label'     => esc_html__( 'More Button BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-read-more .knsl-btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'more_button_typography',
				'label'     => esc_html__( 'More Button Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-read-more .knsl-btn',
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render Services List.
	 *
	 * @since 1.0
	 */

	protected function get_services_items_custom() {
		$items = [];

		$args = array(
			'post_type'			=> 'mphb_room_service',
			'post_status'		=> 'publish',
			'posts_per_page'	=> -1
		);

		$services_items = new \WP_Query( $args );

		while ( $services_items->have_posts() ) : $services_items->the_post();
			$items[get_the_ID()] = get_the_title();
		endwhile; wp_reset_postdata();

		return $items;
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'more', 'none' );
		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );

		$paged = ( get_query_var( 'paged' ) ) ? absint( get_query_var( 'paged' ) ) : 1;
		$page_id = get_the_ID();
		$ids = '';

		if ( $settings['source'] == 'custom' ) {
			$ids = $settings['source_custom'];
		} else {
		}

		$args = array(
			'post_type'			=> 'mphb_room_service',
			'post_status'		=> 'publish',
			'orderby'			=> $settings['sort'],
			'order'				=> $settings['order'],
			'posts_per_page'	=> $settings['limit'],
			'paged' 			=> $paged
		);

		if ( $settings['source'] == 'custom' ) {
			$args += array( 'post__in' => $ids );
		}

		if ( $settings['layout'] == 'column-1' ) {
			$item_classes = 'col-lg-12';
		} elseif ( $settings['layout'] == 'column-2' ) {
			$item_classes = 'col-lg-6';
		} else {
			$item_classes = 'col-lg-4';
		}

		$attr_classes = '';

		if ( $settings['attr_title'] == 'false' ) {
      $attr_classes .= ' attr-title-false';
    }
		if ( $settings['attr_excerpt'] == 'false' ) {
      $attr_classes .= ' attr-desc-false';
    }
		if ( $settings['attr_price'] == 'false' ) {
      $attr_classes .= ' attr-price-false';
    }
		if ( $settings['attr_view_button'] == 'false' ) {
      $attr_classes .= ' attr-readmore-false';
    }

		$q = new \WP_Query( $args );

		?>

		<!-- services -->
    <section class="knsl-p-0-80">
      <div class="container">
        <div class="row <?php echo esc_attr( $attr_classes ); ?>">
          <?php if ( $settings['title'] || $settings['more'] || $settings['description'] ) : ?>
          <div class="col-lg-12">
            <div class="knsl-center knsl-title-frame knsl-scroll-animation knsl-mb-100">
              <?php if ( $settings['title'] ) : ?>
              <<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
            	<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
			          	<?php echo wp_kses_post( $settings['title'] ); ?>
			        </span>
              </<?php echo esc_attr( $settings['title_tag'] ); ?>>
              <?php endif; ?>
              <?php if ( $settings['description'] ) : ?>
              <div class="knsl-text knsl-mb-30">
              	<p>
              		<span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
				          		<?php echo wp_kses_post( $settings['description'] ); ?>
				        	</span>
		        		</p>
              </div>
              <?php endif; ?>
              <?php if ( $settings['more'] ) : ?>
              <a<?php if ( $settings['link'] ) : if ( $settings['link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['link']['url'] ); ?>"<?php endif; ?> class="knsl-btn knsl-btn-md">
              	<span <?php echo $this->get_render_attribute_string( 'more' ); ?>>
				          	<?php echo wp_kses_post( $settings['more'] ); ?>
				        </span>
              </a>
              <?php endif; ?>
            </div>
          </div>
          <?php endif; ?>

          <?php if ( $q->have_posts() ) : ?>
          <?php $i=0; while ( $q->have_posts() ) : $q->the_post(); $i++; ?>
          <div class="<?php echo esc_attr( $item_classes ); ?>">

						<?php
						set_query_var( 'layout', $settings['layout'] );
						set_query_var( 'index', $i );
						get_template_part( 'template-parts/content', 'service' ); ?>

          </div>
          <?php endwhile; ?>

					<?php if ( $settings['pagination'] == 'pages' ) : ?>
					<!-- pagination -->
	        <div class="knsl-pagination">
	          <?php
	            $big = 999999999; // need an unlikely integer

	            echo paginate_links( array(
	              'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	              'format' => '?paged=%#%',
	              'current' => max( 1, get_query_var('paged') ),
	              'total' => $q->max_num_pages,
	              'prev_text' => esc_html__( 'Prev', 'kinsley-plugin' ),
	              'next_text' => esc_html__( 'Next', 'kinsley-plugin' ),
	            ) );
	          ?>
	        </div>
	        <!-- pagination end -->
				  <?php endif; ?>

					<?php if ( $settings['pagination'] == 'button' ) : ?>
					<!-- read more -->
					<div class="knsl-read-more">
						<?php if ( $settings['more_text'] ) : ?>
						<div class="knsl-text">
							<span <?php echo $this->get_render_attribute_string( 'more_text' ); ?>>
								<?php echo wp_kses_post( $settings['more_text'] ); ?>
							</span>
						</div>
						<?php endif; ?>
						<a<?php if ( $settings['more_btn_link'] ) : ?><?php if ( $settings['more_btn_link']['is_external'] ) : ?> target="_blank"<?php endif; ?><?php if ( $settings['more_btn_link']['nofollow'] ) : ?> rel="nofollow"<?php endif; ?> href="<?php echo esc_url( $settings['more_btn_link']['url'] ); ?>"<?php endif; ?> class="knsl-btn">
							<span <?php echo $this->get_render_attribute_string( 'more_btn_txt' ); ?>>
								<?php echo wp_kses_post( $settings['more_btn_txt'] ); ?>
							</span>
						</a>
					</div>
					<!-- read more end -->
		      <?php endif; ?>
		      <?php else :
						get_template_part( 'template-parts/content', 'none' );
				  endif; wp_reset_postdata(); ?>
        </div>
      </div>
    </section>
    <!-- services end -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Services_Widget() );
