<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Kinsley Team Widget.
 *
 * @since 1.0
 */

class Kinsley_Team_Widget extends Widget_Base {

	public function get_name() {
		return 'kinsley-team';
	}

	public function get_title() {
		return esc_html__( 'Team', 'kinsley-plugin' );
	}

	public function get_icon() {
		return 'eicon-parallax';
	}

	public function get_categories() {
		return [ 'kinsley-category' ];
	}

	/**
	 * Register widget controls.
	 *
	 * @since 1.0
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'title_tab',
			[
				'label' => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Title', 'kinsley-plugin' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'h2',
				'options' => [
					'h1'  => __( 'H1', 'kinsley-plugin' ),
					'h2' => __( 'H2', 'kinsley-plugin' ),
					'h3' => __( 'H3', 'kinsley-plugin' ),
					'h4' => __( 'H4', 'kinsley-plugin' ),
					'div' => __( 'DIV', 'kinsley-plugin' ),
				],
			]
		);

		$this->add_control(
			'description',
			[
				'label'       => esc_html__( 'Description', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter description', 'kinsley-plugin' ),
				'default'     => esc_html__( 'Description', 'kinsley-plugin' ),
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_tab',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'image', [
				'label' => esc_html__( 'Image', 'kinsley-plugin' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'name', [
				'label'       => esc_html__( 'Name', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter name', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Name', 'kinsley-plugin' ),
			]
		);

		$repeater->add_control(
			'role', [
				'label'       => esc_html__( 'Role', 'kinsley-plugin' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => esc_html__( 'Enter role', 'kinsley-plugin' ),
				'default'	=> esc_html__( 'Role', 'kinsley-plugin' ),
			]
		);

		$repeater->add_control(
			'social',
			[
				'label'       => esc_html__( 'Social', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$repeater->add_control(
			'social_1',
			[
				'label'       => esc_html__( 'Social #1', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_1_icon', [
				'label'       => esc_html__( 'Icon (#1)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_1' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_1_link', [
				'label'       => esc_html__( 'URL (#1)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_1' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_1_title', [
				'label'       => esc_html__( 'Title (#1)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_1' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_2',
			[
				'label'       => esc_html__( 'Social #2', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_2_icon', [
				'label'       => esc_html__( 'Icon (#2)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_2' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_2_link', [
				'label'       => esc_html__( 'URL (#2)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_2' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_2_title', [
				'label'       => esc_html__( 'Title (#2)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_2' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_3',
			[
				'label'       => esc_html__( 'Social #3', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_3_icon', [
				'label'       => esc_html__( 'Icon (#3)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_3' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_3_link', [
				'label'       => esc_html__( 'URL (#3)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_3' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_3_title', [
				'label'       => esc_html__( 'Title (#3)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_3' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_4',
			[
				'label'       => esc_html__( 'Social #4', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_4_icon', [
				'label'       => esc_html__( 'Icon (#4)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_4' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_4_link', [
				'label'       => esc_html__( 'URL (#4)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_4' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_4_title', [
				'label'       => esc_html__( 'Title (#4)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_4' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_5',
			[
				'label'       => esc_html__( 'Social #5', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_5_icon', [
				'label'       => esc_html__( 'Icon (#5)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_5' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_5_link', [
				'label'       => esc_html__( 'URL (#5)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_5' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_5_title', [
				'label'       => esc_html__( 'Title (#5)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_5' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_6',
			[
				'label'       => esc_html__( 'Social #6', 'kinsley-plugin' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'kinsley-plugin' ),
				'label_off' => __( 'Hide', 'kinsley-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
				'condition' => [
					'social' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_6_icon', [
				'label'       => esc_html__( 'Icon (#6)', 'kinsley-plugin' ),
				'type' => Controls_Manager::ICONS,
				'condition' => [
					'social_6' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_6_link', [
				'label'       => esc_html__( 'URL (#6)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter URL', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_6' => 'yes',
				],
			]
		);

		$repeater->add_control(
			'social_6_title', [
				'label'       => esc_html__( 'Title (#6)', 'kinsley-plugin' ),
				'label_block' => true,
				'type'        => Controls_Manager::TEXT,
				'placeholder' => esc_html__( 'Enter title', 'kinsley-plugin' ),
				'default'	=> '',
				'condition' => [
					'social_6' => 'yes',
				],
			]
		);

		$this->add_control(
			'items',
			[
				'label' => esc_html__( 'Items', 'kinsley-plugin' ),
				'type' => Controls_Manager::REPEATER,
				'prevent_empty' => false,
				'fields' => $repeater->get_controls(),
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'settings_tab',
			[
				'label' => esc_html__( 'Settings', 'kinsley-plugin' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'layout',
			[
				'label'       => esc_html__( 'Layout', 'kinsley-plugin' ),
				'type'        => Controls_Manager::SELECT,
				'default' => 'columns-4',
				'options' => [
					'columns-4'  => __( '4 Columns', 'kinsley-plugin' ),
					'columns-3' => __( '3 Columns', 'kinsley-plugin' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_styling',
			[
				'label'     => esc_html__( 'Title', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-title--h' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-title--h',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'     => esc_html__( 'Description Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-title-frame .knsl-text' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'desc_typography',
				'label'     => esc_html__( 'Description Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-title-frame .knsl-text',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'items_styling',
			[
				'label'     => esc_html__( 'Items', 'kinsley-plugin' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'item_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-team-card .knsl-team-member-descr h3' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_title_typography',
				'label'     => esc_html__( 'Title Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-team-card .knsl-team-member-descr h3',
			]
		);

		$this->add_control(
			'item_role_color',
			[
				'label'     => esc_html__( 'Role Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-team-card .knsl-team-member-descr div' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'item_role_typography',
				'label'     => esc_html__( 'Role Typography', 'kinsley-plugin' ),
				'selector' => '{{WRAPPER}} .knsl-team-card .knsl-team-member-descr div',
			]
		);

		$this->add_control(
			'item_social_color',
			[
				'label'     => esc_html__( 'Social Link Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-team-card .knsl-team-member-descr .knsl-member-social li a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'item_social_bgcolor',
			[
				'label'     => esc_html__( 'Social Link BG Color', 'kinsley-plugin' ),
				'type'      => Controls_Manager::COLOR,
				'default'	=> '',
				'selectors' => [
					'{{WRAPPER}} .knsl-team-card .knsl-team-member-descr .knsl-member-social li a' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Render widget output on the frontend.
	 *
	 * @since 1.0
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_inline_editing_attributes( 'title', 'basic' );
		$this->add_inline_editing_attributes( 'description', 'basic' );

		$col_class = 'col-12 col-md-6 col-lg-3';

		if ( $settings['layout'] == 'columns-3' ) {
			$col_class = 'col-12 col-md-4';
		}

		?>

		<!-- team -->
    <section class="knsl-p-0-80">
      <div class="container">
        <div class="row">
					<?php if ( $settings['title'] || $settings['description'] ) : ?>
          <div class="col-lg-12">
            <div class="knsl-center knsl-title-frame knsl-mb-100">
							<?php if ( $settings['title'] ) : ?>
							<<?php echo esc_attr( $settings['title_tag'] ); ?> class="knsl-title--h knsl-mb-20">
								<span <?php echo $this->get_render_attribute_string( 'title' ); ?>>
										<?php echo wp_kses_post( $settings['title'] ); ?>
								</span>
							</<?php echo esc_attr( $settings['title_tag'] ); ?>>
							<?php endif; ?>
							<?php if ( $settings['description'] ) : ?>
							<div class="knsl-text knsl-mb-30">
								<p>
									<span <?php echo $this->get_render_attribute_string( 'description' ); ?>>
											<?php echo wp_kses_post( $settings['description'] ); ?>
									</span>
								</p>
							</div>
							<?php endif; ?>
						</div>
          </div>
					<?php endif; ?>
					<?php if ( $settings['items'] ) : ?>
					<?php foreach ( $settings['items'] as $index => $item ) :
						$item_name = $this->get_repeater_setting_key( 'name', 'items', $index );
						$this->add_inline_editing_attributes( $item_name, 'basic' );

						$item_role = $this->get_repeater_setting_key( 'role', 'items', $index );
						$this->add_inline_editing_attributes( $item_role, 'basic' );
					?>
          <div class="<?php echo esc_attr( $col_class ); ?>">

            <div class="knsl-team-card">
							<?php if ( $item['image'] ) : $image = wp_get_attachment_image_url( $item['image']['id'], 'kinsley_950xAuto' ); ?>
							<div class="knsl-photo-frame">
                <img src="<?php echo esc_url( $image ); ?>" alt="" />
              </div>
							<?php endif; ?>
              <div class="knsl-team-member-descr">
								<?php if ( $item['name'] ) : ?>
								<h3 class="knsl-mb-10">
									<span <?php echo $this->get_render_attribute_string( $item_name ); ?>>
										<?php echo wp_kses_post( $item['name'] ); ?>
									</span>
								</h3>
								<?php endif; ?>
								<?php if ( $item['role'] ) : ?>
                <div>
									<span <?php echo $this->get_render_attribute_string( $item_role ); ?>>
										<?php echo wp_kses_post( $item['role'] ); ?>
									</span>
								</div>
								<?php endif; ?>
								<?php if ( $item['social'] == 'yes' ) : ?>
                <ul class="knsl-member-social">
									<?php if ( $item['social_1'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_1_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_1_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_1_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
									<?php if ( $item['social_2'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_2_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_2_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_2_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
									<?php if ( $item['social_3'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_3_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_3_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_3_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
									<?php if ( $item['social_4'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_4_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_4_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_4_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
									<?php if ( $item['social_5'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_5_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_5_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_5_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
									<?php if ( $item['social_6'] == 'yes' ) : ?>
                  <li>
										<a href="<?php echo esc_url( $item['social_6_link'] ); ?>" target="_blank" title="<?php echo esc_attr( $item['social_6_title'] ); ?>">
												<?php \Elementor\Icons_Manager::render_icon( $item['social_6_icon'], [ 'aria-hidden' => 'true' ] ); ?>
										</a>
									</li>
									<?php endif; ?>
                </ul>
								<?php endif; ?>
              </div>
            </div>

          </div>
					<?php endforeach; ?>
					<?php endif; ?>
        </div>
      </div>
    </section>
    <!-- team end -->

		<?php
	}

	/**
	 * Render widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function content_template() { ?>

		<#
		view.addInlineEditingAttributes( 'title', 'basic' );
		view.addInlineEditingAttributes( 'description', 'basic' );

		var col_class = 'col-12 col-md-6 col-lg-3';

		if ( settings.layout == 'columns-3' ) {
			col_class = 'col-12 col-md-4';
		}
		#>

		<!-- team -->
    <section class="knsl-p-0-80">
      <div class="container">
        <div class="row">
					<# if ( settings.title || settings.description ) { #>
          <div class="col-lg-12">
            <div class="knsl-center knsl-title-frame knsl-mb-100">
							<# if ( settings.title ) { #>
							<{{{ settings.title_tag }}} class="knsl-title--h knsl-mb-20">
								<span {{{ view.getRenderAttributeString( 'title' ) }}}>
										{{{ settings.title }}}
								</span>
							</{{{ settings.title_tag }}}>
							<# } #>
							<# if ( settings.description ) { #>
							<div class="knsl-text knsl-mb-30">
								<p>
									<span {{{ view.getRenderAttributeString( 'description' ) }}}>
											{{{ settings.description }}}
									</span>
								</p>
							</div>
							<# } #>
						</div>
          </div>
					<# } #>
					<# if ( settings.items ) { #>
					<# _.each( settings.items, function( item, index ) {
						var item_name = view.getRepeaterSettingKey( 'name', 'items', index );
						view.addInlineEditingAttributes( item_name, 'basic' );

						var item_role = view.getRepeaterSettingKey( 'role', 'items', index );
						view.addInlineEditingAttributes( item_role, 'basic' );

						var social_1_iconHTML = elementor.helpers.renderIcon( view, item.social_1_icon, { 'aria-hidden': true }, 'i' , 'object' );
						var social_2_iconHTML = elementor.helpers.renderIcon( view, item.social_2_icon, { 'aria-hidden': true }, 'i' , 'object' );
						var social_3_iconHTML = elementor.helpers.renderIcon( view, item.social_3_icon, { 'aria-hidden': true }, 'i' , 'object' );
						var social_4_iconHTML = elementor.helpers.renderIcon( view, item.social_4_icon, { 'aria-hidden': true }, 'i' , 'object' );
						var social_5_iconHTML = elementor.helpers.renderIcon( view, item.social_5_icon, { 'aria-hidden': true }, 'i' , 'object' );
						var social_6_iconHTML = elementor.helpers.renderIcon( view, item.social_6_icon, { 'aria-hidden': true }, 'i' , 'object' );
					#>
          <div class="{{{ col_class }}}">

            <div class="knsl-team-card">
							<# if ( item.image ) { #>
							<div class="knsl-photo-frame">
              	<img src="{{{ item.image.url }}}" alt="" />
              </div>
							<# } #>
              <div class="knsl-team-member-descr">
								<# if ( item.name ) { #>
								<h3 class="knsl-mb-10">
									<span {{{ view.getRenderAttributeString( item_name ) }}}>
										{{{ item.name }}}
									</span>
								</h3>
								<# } #>
								<# if ( item.role ) { #>
                <div>
									<span {{{ view.getRenderAttributeString( item_role ) }}}>
										{{{ item.role }}}
									</span>
								</div>
								<# } #>
								<# if ( item.social == 'yes' ) { #>
                <ul class="knsl-member-social">
									<# if ( item.social_1 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_1_link }}}" target="_blank" title="{{{ item.social_1_title }}}">
												{{{ social_1_iconHTML.value }}}
										</a>
									</li>
									<# } #>
									<# if ( item.social_2 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_2_link }}}" target="_blank" title="{{{ item.social_2_title }}}">
												{{{ social_2_iconHTML.value }}}
										</a>
									</li>
									<# } #>
									<# if ( item.social_3 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_3_link }}}" target="_blank" title="{{{ item.social_3_title }}}">
												{{{ social_3_iconHTML.value }}}
										</a>
									</li>
									<# } #>
									<# if ( item.social_4 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_4_link }}}" target="_blank" title="{{{ item.social_4_title }}}">
												{{{ social_4_iconHTML.value }}}
										</a>
									</li>
									<# } #>
									<# if ( item.social_5 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_5_link }}}" target="_blank" title="{{{ item.social_5_title }}}">
												{{{ social_5_iconHTML.value }}}
										</a>
									</li>
									<# } #>
									<# if ( item.social_6 == 'yes' ) { #>
                  <li>
										<a href="{{{ item.social_6_link }}}" target="_blank" title="{{{ item.social_6_title }}}">
												{{{ social_6_iconHTML.value }}}
										</a>
									</li>
									<# } #>
                </ul>
								<# } #>
              </div>
            </div>

          </div>
					<# }); #>
					<# } #>
        </div>
      </div>
    </section>
    <!-- team end -->ß

	<?php }
}

Plugin::instance()->widgets_manager->register_widget_type( new Kinsley_Team_Widget() );
