<?php

/**
 * Register Custom Post Type: Header & Footer
 */
function kinsley_register_hf_templates() {
	$labels = array(
		'name'                  => esc_html__( 'Header & Footer', 'kinsley-plugin' ),
		'singular_name'         => esc_html__( 'Template', 'kinsley-plugin' ),
		'add_new_item'          => esc_html__( 'Add New Template', 'kinsley-plugin' ),
		'add_new'               => esc_html__( 'Add New', 'kinsley-plugin' ),
    'new_item'              => esc_html__( 'Add New Template', 'kinsley-plugin' ),
    'all_items'             => esc_html__( 'All Templates', 'kinsley-plugin' ),
		'edit_item'             => esc_html__( 'Edit Template', 'kinsley-plugin' ),
		'view_item'             => esc_html__( 'View Template', 'kinsley-plugin' ),
		'search_items'          => esc_html__( 'Search Template', 'kinsley-plugin' ),
		'not_found'             => esc_html__( 'No Templates Found', 'kinsley-plugin' ),
		'not_found_in_trash'    => esc_html__( 'No Templates Found in Trash', 'kinsley-plugin' ),
	);
	$args = array(
		'label'                 => esc_html__( 'Header & Footer', 'kinsley-plugin' ),
		'description'           => esc_html__( 'Add a Template', 'kinsley-plugin' ),
		'supports' 							=> array( 'title','editor','author','elementor' ),
		'hierarchical'          => false,
		'show_in_menu' 					=> true,
		'show_in_nav_menus'     => false,
		'show_in_admin_bar' 		=> true,
		'public'                => true,
		'show_ui'               => true,
		'exclude_from_search'   => true,
		'publicly_queryable' 		=> true,
		'has_archive' 					=> false,
		'menu_position'         => 58,
		'menu_icon'             => 'dashicons-editor-insertmore',
		'can_export'            => true,
    'capability_type'       => 'post',
		'rewrite' 							=> array( 'slug' => 'hf_templates' ),
		'labels'                => $labels,
	);
	register_post_type( 'hf_templates', $args );
}
add_action( 'init', 'kinsley_register_hf_templates');

function kinsley_hf_default_page_template() {
  global $post;
  if ( 'hf_templates' == $post->post_type
      && 0 != count( get_page_templates( $post ) )
      && get_option( 'page_for_posts' ) != $post->ID // Not the page for listing posts
      && '' == $post->page_template // Only when page_template is not set
  ) {
		$post->page_template = "elementor_canvas";
  }
}
add_action( 'add_meta_boxes', 'kinsley_hf_default_page_template', 1 );

/**
 * Register Custom Post Type: Gallery
 */
function kinsley_register_gallery() {
	$labels = array(
		'name' => esc_html__( 'Gallery', 'kinsley-plugin' ),
		'singular_name' => esc_html__( 'Gallery', 'kinsley-plugin' ),
		'menu_name' => esc_html__( 'Gallery', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent Image:', 'kinsley-plugin' ),
		'all_items' => esc_html__( 'All Images', 'kinsley-plugin' ),
		'view_item' => esc_html__( 'View Image', 'kinsley-plugin' ),
		'add_new_item' => esc_html__( 'Add New Image', 'kinsley-plugin' ),
		'add_new' => esc_html__( 'New Image', 'kinsley-plugin' ),
		'edit_item' => esc_html__( 'Edit Image', 'kinsley-plugin' ),
		'update_item' => esc_html__( 'Update Image', 'kinsley-plugin' ),
		'search_items' => esc_html__( 'Search Images', 'kinsley-plugin' ),
		'not_found' => esc_html__( 'No images found', 'kinsley-plugin' ),
		'not_found_in_trash' => esc_html__( 'No images found in Trash', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'Gallery', 'kinsley-plugin' ),
	  'description' => esc_html__( 'Gallery', 'kinsley-plugin' ),
	  'supports' => array( 'title','revisions','thumbnail','page-attributes' ),
	  'taxonomies' => array( 'gallery_categories' ),
	  'hierarchical' => false,
	  'public' => true,
	  'show_ui' => true,
	  'show_in_menu' => true,
	  'show_in_nav_menus' => false,
	  'show_in_admin_bar' => true,
	  'menu_position' => 55,
	  'menu_icon' => 'dashicons-images-alt2',
	  'can_export' => true,
	  'has_archive' => false,
	  'exclude_from_search' => true,
	  'publicly_queryable' => false,
		'query_var'           => true,
	  'capability_type' => 'post',
	  'rewrite' => array( 'slug' => 'gallery/item', 'with_front' => true  ),
		'labels' => $labels,
	);
	register_post_type( 'gallery', $args );
}
add_action( 'init', 'kinsley_register_gallery' );

function kinsley_register_gallery_categories() {
	$labels = array(
		'name'              => esc_html__( 'Gallery Categories', 'kinsley-plugin' ),
		'singular_name'     => esc_html__( 'Gallery Categories', 'kinsley-plugin' ),
		'search_items'      => esc_html__( 'Search Gallery Categories', 'kinsley-plugin' ),
		'all_items'         => esc_html__( 'All Gallery Categories', 'kinsley-plugin' ),
		'parent_item'       => esc_html__( 'Parent Gallery Category', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent Gallery Category:', 'kinsley-plugin' ),
		'edit_item'         => esc_html__( 'Edit Gallery Category', 'kinsley-plugin' ),
		'update_item'       => esc_html__( 'Update Gallery Category', 'kinsley-plugin' ),
		'add_new_item'      => esc_html__( 'Add New Gallery Category', 'kinsley-plugin' ),
		'new_item_name'     => esc_html__( 'New Gallery Category Name', 'kinsley-plugin' ),
		'menu_name'         => esc_html__( 'Gallery Categories', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'Gallery Categories', 'kinsley-plugin' ),
		'hierarchical' => true,
		'show_ui' => true,
		'show_in_nav_menus' => false,
		'show_admin_column' => true,
		'query_var' => true,
		'has_archive' => false,
		'rewrite' => array( 'slug' => 'gallery/category' ),
		'labels' => $labels,
	);
	register_taxonomy( 'gallery_categories', array ( 0 => 'gallery' ), $args );
}
add_action( 'init', 'kinsley_register_gallery_categories' );

/**
 * Register Custom Post Type: Restaurant Menu
 */
function kinsley_register_restaurant_menu() {
	$labels = array(
		'name' => esc_html__( 'Restaurant Menu', 'kinsley-plugin' ),
		'singular_name' => esc_html__( 'Restaurant Menu', 'kinsley-plugin' ),
		'menu_name' => esc_html__( 'Restaurant', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent Menu Item:', 'kinsley-plugin' ),
		'all_items' => esc_html__( 'All Menu Items', 'kinsley-plugin' ),
		'view_item' => esc_html__( 'View Menu Item', 'kinsley-plugin' ),
		'add_new_item' => esc_html__( 'Add New Menu Item', 'kinsley-plugin' ),
		'add_new' => esc_html__( 'New Menu Item', 'kinsley-plugin' ),
		'edit_item' => esc_html__( 'Edit Menu Item', 'kinsley-plugin' ),
		'update_item' => esc_html__( 'Update Menu Item', 'kinsley-plugin' ),
		'search_items' => esc_html__( 'Search Menu Item', 'kinsley-plugin' ),
		'not_found' => esc_html__( 'No Menu Item found', 'kinsley-plugin' ),
		'not_found_in_trash' => esc_html__( 'No Menu Item found in Trash', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'Restaurant Menu', 'kinsley-plugin' ),
		'description' => esc_html__( 'Restaurant Menu', 'kinsley-plugin' ),
		'supports' => array( 'title','revisions','thumbnail','page-attributes' ),
		'taxonomies' => array( 'restaurant_menu_categories', 'post_tag' ),
		'hierarchical' => false,
		'public' => true,
		'show_ui' => true,
		'show_in_menu' => true,
		'show_in_nav_menus' => false,
		'show_in_admin_bar' => true,
		'menu_position' => 56,
		'menu_icon' => 'dashicons-image-filter',
		'can_export' => true,
		'has_archive' => false,
		'exclude_from_search' => true,
		'publicly_queryable' => false,
		'capability_type' => 'post',
		'rewrite' => array( 'slug' => 'restaurant/item', 'with_front' => true  ),
		'labels' => $labels,
	);
	register_post_type( 'restaurant_menu', $args );
}
add_action( 'init', 'kinsley_register_restaurant_menu' );

function kinsley_register_restaurant_menu_categories() {
	$labels = array(
		'name'              => esc_html__( 'Restaurant Menu Categories', 'kinsley-plugin' ),
		'singular_name'     => esc_html__( 'Restaurant Menu Categories', 'kinsley-plugin' ),
		'search_items'      => esc_html__( 'Search Menu Categories', 'kinsley-plugin' ),
		'all_items'         => esc_html__( 'All Menu Categories', 'kinsley-plugin' ),
		'parent_item'       => esc_html__( 'Parent Menu Category', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent Menu Category:', 'kinsley-plugin' ),
		'edit_item'         => esc_html__( 'Edit Menu Category', 'kinsley-plugin' ),
		'update_item'       => esc_html__( 'Update Menu Category', 'kinsley-plugin' ),
		'add_new_item'      => esc_html__( 'Add New Menu Category', 'kinsley-plugin' ),
		'new_item_name'     => esc_html__( 'New Menu Category Name', 'kinsley-plugin' ),
		'menu_name'         => esc_html__( 'Restaurant Menu Categories', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'Restaurant Menu Categories', 'kinsley-plugin' ),
		'hierarchical' => true,
		'show_ui' => true,
		'show_in_nav_menus' => false,
		'show_admin_column' => true,
		'query_var' => true,
		'has_archive' => false,
		'rewrite' => array( 'slug' => 'restaurant/category' ),
		'labels' => $labels,
	);
	register_taxonomy( 'restaurant_menu_categories', array ( 0 => 'restaurant_menu' ), $args );
}
add_action( 'init', 'kinsley_register_restaurant_menu_categories' );

/**
 * Register Custom Post Type: FAQ
 */
function kinsley_register_faq() {
	$labels = array(
		'name' => esc_html__( 'FAQ', 'kinsley-plugin' ),
		'singular_name' => esc_html__( 'FAQ', 'kinsley-plugin' ),
		'menu_name' => esc_html__( 'FAQ', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent FAQ Item:', 'kinsley-plugin' ),
		'all_items' => esc_html__( 'All FAQ Items', 'kinsley-plugin' ),
		'view_item' => esc_html__( 'View FAQ Item', 'kinsley-plugin' ),
		'add_new_item' => esc_html__( 'Add New FAQ Item', 'kinsley-plugin' ),
		'add_new' => esc_html__( 'New FAQ Item', 'kinsley-plugin' ),
		'edit_item' => esc_html__( 'Edit FAQ Item', 'kinsley-plugin' ),
		'update_item' => esc_html__( 'Update FAQ Item', 'kinsley-plugin' ),
		'search_items' => esc_html__( 'Search FAQ Item', 'kinsley-plugin' ),
		'not_found' => esc_html__( 'No FAQ Item found', 'kinsley-plugin' ),
		'not_found_in_trash' => esc_html__( 'No FAQ Item found in Trash', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'FAQ', 'kinsley-plugin' ),
		'description' => esc_html__( 'FAQ', 'kinsley-plugin' ),
		'supports' => array( 'title','editor','revisions','page-attributes' ),
		'taxonomies' => array( 'faq_categories' ),
		'hierarchical' => false,
		'public' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'show_in_nav_menus' => false,
		'show_in_admin_bar' => true,
		'menu_position' => 57,
		'menu_icon' => 'dashicons-info-outline',
		'can_export' => true,
		'has_archive' => false,
		'exclude_from_search' => true,
		'publicly_queryable' => false,
		'capability_type' => 'post',
		'rewrite' => array( 'slug' => 'faq/item', 'with_front' => true  ),
		'labels' => $labels,
	);
	register_post_type( 'faq', $args );
}
add_action( 'init', 'kinsley_register_faq' );

function kinsley_register_faq_categories() {
	$labels = array(
		'name'              => esc_html__( 'FAQ Categories', 'kinsley-plugin' ),
		'singular_name'     => esc_html__( 'FAQ Categories', 'kinsley-plugin' ),
		'search_items'      => esc_html__( 'Search FAQ Categories', 'kinsley-plugin' ),
		'all_items'         => esc_html__( 'All FAQ Categories', 'kinsley-plugin' ),
		'parent_item'       => esc_html__( 'Parent FAQ Category', 'kinsley-plugin' ),
		'parent_item_colon' => esc_html__( 'Parent FAQ Category:', 'kinsley-plugin' ),
		'edit_item'         => esc_html__( 'Edit FAQ Category', 'kinsley-plugin' ),
		'update_item'       => esc_html__( 'Update FAQ Category', 'kinsley-plugin' ),
		'add_new_item'      => esc_html__( 'Add New FAQ Category', 'kinsley-plugin' ),
		'new_item_name'     => esc_html__( 'New FAQ Category Name', 'kinsley-plugin' ),
		'menu_name'         => esc_html__( 'FAQ Categories', 'kinsley-plugin' ),
	);
	$args = array(
		'label' => esc_html__( 'FAQ Categories', 'kinsley-plugin' ),
		'hierarchical' => true,
		'show_ui' => true,
		'show_in_nav_menus' => false,
		'show_admin_column' => true,
		'query_var' => true,
		'has_archive' => false,
		'rewrite' => array( 'slug' => 'faq/category' ),
		'labels' => $labels,
	);
	register_taxonomy( 'faq_categories', array ( 0 => 'faq' ), $args );
}
add_action( 'init', 'kinsley_register_faq_categories' );
